/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer 
*
* Copyright (C) 2012 Renesas Electronics Corporation. All rights reserved.    
*******************************************************************************/
/******************************************************************************
* File Name    : r_flash_rx63n.h
* Description  : This file has specific information about the ROM and DF on 
*                RX63N/RX631 Group MCUs.
*******************************************************************************
* History : DD.MM.YYYY Version Description
*         : 11.09.2012 1.00    First Release
*         : 10.10.2012 1.10    Added FCU_RAM_INIT_REQUIRED macro.
*         : 01.12.2015 1.20    Fixed incorrect FLASH_CF_BLOCK_INVALID value
*         : 10.08.2016 2.00    Modified for BSPless flash.
*         : 17.11.2016 2.10    Added FLASH_xxx size and num block defines
******************************************************************************/

#ifndef FLASH_API_RX63N_H
#define FLASH_API_RX63N_H

/******************************************************************************
Includes   <System Includes> , "Project Includes"
******************************************************************************/
/* Defines standard typedefs used in this file */
#include <stdint.h>
#include "r_mcu_config.h"

/******************************************************************************
Macro definitions
******************************************************************************/
/* Defines the number of flash areas */
#define NUM_ROM_AREAS           4
/* Defines the start program/erase address for the different flash areas */
#define ROM_AREA_0              (0x00F80000)
#define ROM_AREA_1              (0x00F00000)
#define ROM_AREA_2              (0x00E80000)
#define ROM_AREA_3              (0x00E00000)    
   
/* Defines whether this MCU requires the FCU RAM be enabled and initialized.
   If uncommented, then MCU is required to init FCU RAM.
   If commented out, then MCU is not required. */
#define FCU_RAM_INIT_REQUIRED   (1)

/*  Bottom of DF Area */
#define DF_ADDRESS              0x00100000
/* Used for getting DF block */
#define DF_MASK                 0xFFFFF800
/* Used for getting erase boundary in DF block when doing blank checking */
#define DF_ERASE_BLOCK_SIZE     0x00000020
/* Defines how many DF blocks are on this part */
#define DF_NUM_BLOCKS           1024
/* THis is the last address in the last block, not the starting address */
#define FLASH_DF_LAST_BLOCK        ((FLASH_DF_BLOCK_INVALID) - (DF_ERASE_BLOCK_SIZE))

/* Defines how many ROM blocks are on this part */
#if MCU_ROM_SIZE_BYTES == 2097152
    #define ROM_NUM_BLOCKS      70    //2MB part
#elif MCU_ROM_SIZE_BYTES == 1572864
    #define ROM_NUM_BLOCKS      62    //1.5MB part
#elif MCU_ROM_SIZE_BYTES == 1048576
    #define ROM_NUM_BLOCKS      54    //1MB part
#elif MCU_ROM_SIZE_BYTES == 786432
    #define ROM_NUM_BLOCKS      46    //768KB part
#elif MCU_ROM_SIZE_BYTES == 524288
    #define ROM_NUM_BLOCKS      38    //512KB part
#elif MCU_ROM_SIZE_BYTES == 393216
    #define ROM_NUM_BLOCKS      30    //384KB part
#else
    #error "ERROR - Flash API - This ROM size is not defined. Update r_flash_rx63n.h with this MCUs information."
#endif

/* Programming size for ROM in bytes */
#define ROM_PROGRAM_SIZE        128
/* Programming size for data flash in bytes */
/* NOTE: RX630/631/63N only programs in 2-byte intervals */
#define DF_PROGRAM_SIZE_SMALL   2

#define FLASH_CF_SMALL_BLOCK_SIZE       (4096)
#define FLASH_CF_MEDIUM_BLOCK_SIZE      (16384)
#define FLASH_CF_LARGE_BLOCK_SIZE       (32768)
#define FLASH_CF_XLARGE_BLOCK_SIZE      (65536)
#define FLASH_NUM_BLOCKS_CF             ROM_NUM_BLOCKS
#define FLASH_CF_MIN_PGM_SIZE           ROM_PROGRAM_SIZE
#define FLASH_DF_BLOCK_SIZE             DF_ERASE_BLOCK_SIZE
#define FLASH_NUM_BLOCKS_DF             DF_NUM_BLOCKS
#define FLASH_DF_MIN_PGM_SIZE           DF_PROGRAM_SIZE_SMALL
#define FLASH_DF_HIGHEST_VALID_BLOCK    FLASH_DF_LAST_BLOCK


typedef enum _flash_block_address
{
FLASH_CF_BLOCK_0       = 0x00FFF000,    /*   4KB: 0xFFFFF000 - 0xFFFFFFFF */
FLASH_CF_BLOCK_1       = 0x00FFE000,    /*   4KB: 0xFFFFE000 - 0xFFFFEFFF */
FLASH_CF_BLOCK_2       = 0x00FFD000,    /*   4KB: 0xFFFFD000 - 0xFFFFDFFF */
FLASH_CF_BLOCK_3       = 0x00FFC000,    /*   4KB: 0xFFFFC000 - 0xFFFFCFFF */
FLASH_CF_BLOCK_4       = 0x00FFB000,    /*   4KB: 0xFFFFB000 - 0xFFFFBFFF */
FLASH_CF_BLOCK_5       = 0x00FFA000,    /*   4KB: 0xFFFFA000 - 0xFFFFAFFF */
FLASH_CF_BLOCK_6       = 0x00FF9000,    /*   4KB: 0xFFFF9000 - 0xFFFF9FFF */
FLASH_CF_BLOCK_7       = 0x00FF8000,    /*   4KB: 0xFFFF8000 - 0xFFFF8FFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0x4   //   32KB ROM
    FLASH_CF_BLOCK_INVALID = 0x00FF7FFF,
#else
FLASH_CF_BLOCK_8       = 0x00FF4000,    /*  16KB: 0xFFFF4000 - 0xFFFF7FFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0x5   //   48KB ROM
    FLASH_CF_BLOCK_INVALID = 0x00FF3FFF,
#else
FLASH_CF_BLOCK_9       = 0x00FF0000,    /*  16KB: 0xFFFF0000 - 0xFFFF3FFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0x6   //   64KB ROM
    FLASH_CF_BLOCK_INVALID = 0x00FEFFFF,
#else
FLASH_CF_BLOCK_10      = 0x00FEC000,    /*  16KB: 0xFFFEC000 - 0xFFFEFFFF */
FLASH_CF_BLOCK_11      = 0x00FE8000,    /*  16KB: 0xFFFE8000 - 0xFFFEBFFF */
FLASH_CF_BLOCK_12      = 0x00FE4000,    /*  16KB: 0xFFFE4000 - 0xFFFE7FFF */
FLASH_CF_BLOCK_13      = 0x00FE0000,    /*  16KB: 0xFFFE0000 - 0xFFFE3FFF */
FLASH_CF_BLOCK_14      = 0x00FDC000,    /*  16KB: 0xFFFDC000 - 0xFFFDFFFF */
FLASH_CF_BLOCK_15      = 0x00FD8000,    /*  16KB: 0xFFFD8000 - 0xFFFDBFFF */
FLASH_CF_BLOCK_16      = 0x00FD4000,    /*  16KB: 0xFFFD4000 - 0xFFFD7FFF */
FLASH_CF_BLOCK_17      = 0x00FD0000,    /*  16KB: 0xFFFD0000 - 0xFFFD3FFF */
FLASH_CF_BLOCK_18      = 0x00FCC000,    /*  16KB: 0xFFFCC000 - 0xFFFCFFFF */
FLASH_CF_BLOCK_19      = 0x00FC8000,    /*  16KB: 0xFFFC8000 - 0xFFFCBFFF */
FLASH_CF_BLOCK_20      = 0x00FC4000,    /*  16KB: 0xFFFC4000 - 0xFFFC7FFF */
FLASH_CF_BLOCK_21      = 0x00FC0000,    /*  16KB: 0xFFFC0000 - 0xFFFC3FFF */
FLASH_CF_BLOCK_22      = 0x00FBC000,    /*  16KB: 0xFFFBC000 - 0xFFFBFFFF */
FLASH_CF_BLOCK_23      = 0x00FB8000,    /*  16KB: 0xFFFB8000 - 0xFFFBBFFF */
FLASH_CF_BLOCK_24      = 0x00FB4000,    /*  16KB: 0xFFFB4000 - 0xFFFB7FFF */
FLASH_CF_BLOCK_25      = 0x00FB0000,    /*  16KB: 0xFFFB0000 - 0xFFFB3FFF */
FLASH_CF_BLOCK_26      = 0x00FAC000,    /*  16KB: 0xFFFAC000 - 0xFFFAFFFF */
FLASH_CF_BLOCK_27      = 0x00FA8000,    /*  16KB: 0xFFFA8000 - 0xFFFABFFF */
FLASH_CF_BLOCK_28      = 0x00FA4000,    /*  16KB: 0xFFFA4000 - 0xFFFA7FFF */
FLASH_CF_BLOCK_29      = 0x00FA0000,    /*  16KB: 0xFFFA0000 - 0xFFFA3FFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0x7   //   384KB ROM
    FLASH_CF_BLOCK_INVALID = 0x00F9FFFF,
#else
FLASH_CF_BLOCK_30      = 0x00F9C000,    /*  16KB: 0xFFF9C000 - 0xFFF9FFFF */
FLASH_CF_BLOCK_31      = 0x00F98000,    /*  16KB: 0xFFF98000 - 0xFFF9BFFF */
FLASH_CF_BLOCK_32      = 0x00F94000,    /*  16KB: 0xFFF94000 - 0xFFF97FFF */
FLASH_CF_BLOCK_33      = 0x00F90000,    /*  16KB: 0xFFF90000 - 0xFFF93FFF */
FLASH_CF_BLOCK_34      = 0x00F8C000,    /*  16KB: 0xFFF8C000 - 0xFFF8FFFF */
FLASH_CF_BLOCK_35      = 0x00F88000,    /*  16KB: 0xFFF88000 - 0xFFF8BFFF */
FLASH_CF_BLOCK_36      = 0x00F84000,    /*  16KB: 0xFFF84000 - 0xFFF87FFF */
FLASH_CF_BLOCK_37      = 0x00F80000,    /*  16KB: 0xFFF80000 - 0xFFF83FFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0x8   //   512KB ROM
    FLASH_CF_BLOCK_INVALID = 0x00F7FFFF,
#else
FLASH_CF_BLOCK_38      = 0x00F78000,    /*  32KB: 0xFFF78000 - 0xFFF7FFFF */
FLASH_CF_BLOCK_39      = 0x00F70000,    /*  32KB: 0xFFF70000 - 0xFFF77FFF */
FLASH_CF_BLOCK_40      = 0x00F68000,    /*  32KB: 0xFFF68000 - 0xFFF6FFFF */
FLASH_CF_BLOCK_41      = 0x00F60000,    /*  32KB: 0xFFF60000 - 0xFFF67FFF */
FLASH_CF_BLOCK_42      = 0x00F58000,    /*  32KB: 0xFFF58000 - 0xFFF5FFFF */
FLASH_CF_BLOCK_43      = 0x00F50000,    /*  32KB: 0xFFF50000 - 0xFFF57FFF */
FLASH_CF_BLOCK_44      = 0x00F48000,    /*  32KB: 0xFFF48000 - 0xFFF4FFFF */
FLASH_CF_BLOCK_45      = 0x00F40000,    /*  32KB: 0xFFF40000 - 0xFFF47FFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0xA   //   768KB ROM
    FLASH_CF_BLOCK_INVALID = 0x00F3FFFF,
#else
FLASH_CF_BLOCK_46      = 0x00F38000,    /*  32KB: 0xFFF38000 - 0xFFF3FFFF */
FLASH_CF_BLOCK_47      = 0x00F30000,    /*  32KB: 0xFFF30000 - 0xFFF37FFF */
FLASH_CF_BLOCK_48      = 0x00F28000,    /*  32KB: 0xFFF28000 - 0xFFF2FFFF */
FLASH_CF_BLOCK_49      = 0x00F20000,    /*  32KB: 0xFFF20000 - 0xFFF27FFF */
FLASH_CF_BLOCK_50      = 0x00F18000,    /*  32KB: 0xFFF18000 - 0xFFF1FFFF */
FLASH_CF_BLOCK_51      = 0x00F10000,    /*  32KB: 0xFFF10000 - 0xFFF17FFF */
FLASH_CF_BLOCK_52      = 0x00F08000,    /*  32KB: 0xFFF08000 - 0xFFF0FFFF */
FLASH_CF_BLOCK_53      = 0x00F00000,    /*  32KB: 0xFFF00000 - 0xFFF07FFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0xB   //   1 MB ROM
    FLASH_CF_BLOCK_INVALID = 0x00EFFFFF,
#else
FLASH_CF_BLOCK_54      = 0x00EF0000,    /*  64KB: 0xFFEF0000 - 0xFFEFFFFF */
FLASH_CF_BLOCK_55      = 0x00EE0000,    /*  64KB: 0xFFEE0000 - 0xFFEEFFFF */
FLASH_CF_BLOCK_56      = 0x00ED0000,    /*  64KB: 0xFFED0000 - 0xFFEDFFFF */
FLASH_CF_BLOCK_57      = 0x00EC0000,    /*  64KB: 0xFFEC0000 - 0xFFECFFFF */
FLASH_CF_BLOCK_58      = 0x00EB0000,    /*  64KB: 0xFFEB0000 - 0xFFEBFFFF */
FLASH_CF_BLOCK_59      = 0x00EA0000,    /*  64KB: 0xFFEA0000 - 0xFFEAFFFF */
FLASH_CF_BLOCK_60      = 0x00E90000,    /*  64KB: 0xFFE90000 - 0xFFE9FFFF */
FLASH_CF_BLOCK_61      = 0x00E80000,    /*  64KB: 0xFFE80000 - 0xFFE8FFFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0xD   //   1.5 MB ROM
    FLASH_CF_BLOCK_INVALID = 0x00E7FFFF,
#else
FLASH_CF_BLOCK_62      = 0x00E70000,    /*  64KB: 0xFFE70000 - 0xFFE7FFFF */
FLASH_CF_BLOCK_63      = 0x00E60000,    /*  64KB: 0xFFE60000 - 0xFFE6FFFF */
FLASH_CF_BLOCK_64      = 0x00E50000,    /*  64KB: 0xFFE50000 - 0xFFE5FFFF */
FLASH_CF_BLOCK_65      = 0x00E40000,    /*  64KB: 0xFFE40000 - 0xFFE4FFFF */
FLASH_CF_BLOCK_66      = 0x00E30000,    /*  64KB: 0xFFE30000 - 0xFFE3FFFF */
FLASH_CF_BLOCK_67      = 0x00E20000,    /*  64KB: 0xFFE20000 - 0xFFE2FFFF */
FLASH_CF_BLOCK_68      = 0x00E10000,    /*  64KB: 0xFFE10000 - 0xFFE1FFFF */
FLASH_CF_BLOCK_69      = 0x00E00000,    /*  64KB: 0xFFE00000 - 0xFFE0FFFF */
#if   MCU_CFG_PART_MEMORY_SIZE == 0xE   //   2.0 MB ROM
    FLASH_CF_BLOCK_INVALID = 0x00DFFFFF,
#endif
#endif
#endif
#endif
#endif
#endif
#endif
#endif
#endif
    FLASH_DF_BLOCK_0       = 0x00100000,    /*    32: 0x00100000 - 0x0010001F */
    FLASH_DF_BLOCK_1       = 0x00100020,    /*    32: 0x00100020 - 0x0010003F */
    FLASH_DF_BLOCK_2       = 0x00100040,    /*    32: 0x00100040 - 0x0010005F */
    FLASH_DF_BLOCK_3       = 0x00100060,    /*    32: 0x00100060 - 0x0010007F */
    FLASH_DF_BLOCK_4       = 0x00100080,    /*    32: 0x00100080 - 0x0010009F */
    FLASH_DF_BLOCK_5       = 0x001000A0,    /*    32: 0x001000A0 - 0x001000BF */
    FLASH_DF_BLOCK_6       = 0x001000C0,    /*    32: 0x001000C0 - 0x001000DF */
    FLASH_DF_BLOCK_7       = 0x001000E0,    /*    32: 0x001000E0 - 0x001000FF */
    FLASH_DF_BLOCK_8       = 0x00100100,    /*    32: 0x00100100 - 0x0010011F */
    FLASH_DF_BLOCK_9       = 0x00100120,    /*    32: 0x00100120 - 0x0010013F */
    FLASH_DF_BLOCK_10      = 0x00100140,    /*    32: 0x00100140 - 0x0010015F */
    FLASH_DF_BLOCK_11      = 0x00100160,    /*    32: 0x00100160 - 0x0010017F */
    FLASH_DF_BLOCK_12      = 0x00100180,    /*    32: 0x00100180 - 0x0010019F */
    FLASH_DF_BLOCK_13      = 0x001001A0,    /*    32: 0x001001A0 - 0x001001BF */
    FLASH_DF_BLOCK_14      = 0x001001C0,    /*    32: 0x001001C0 - 0x001001DF */
    FLASH_DF_BLOCK_15      = 0x001001E0,    /*    32: 0x001001E0 - 0x001001FF */
    FLASH_DF_BLOCK_16      = 0x00100200,    /*    32: 0x00100200 - 0x0010021F */
    FLASH_DF_BLOCK_17      = 0x00100220,    /*    32: 0x00100220 - 0x0010023F */
    FLASH_DF_BLOCK_18      = 0x00100240,    /*    32: 0x00100240 - 0x0010025F */
    FLASH_DF_BLOCK_19      = 0x00100260,    /*    32: 0x00100260 - 0x0010027F */
    FLASH_DF_BLOCK_20      = 0x00100280,    /*    32: 0x00100280 - 0x0010029F */
    FLASH_DF_BLOCK_21      = 0x001002A0,    /*    32: 0x001002A0 - 0x001002BF */
    FLASH_DF_BLOCK_22      = 0x001002C0,    /*    32: 0x001002C0 - 0x001002DF */
    FLASH_DF_BLOCK_23      = 0x001002E0,    /*    32: 0x001002E0 - 0x001002FF */
    FLASH_DF_BLOCK_24      = 0x00100300,    /*    32: 0x00100300 - 0x0010031F */
    FLASH_DF_BLOCK_25      = 0x00100320,    /*    32: 0x00100320 - 0x0010033F */
    FLASH_DF_BLOCK_26      = 0x00100340,    /*    32: 0x00100340 - 0x0010035F */
    FLASH_DF_BLOCK_27      = 0x00100360,    /*    32: 0x00100360 - 0x0010037F */
    FLASH_DF_BLOCK_28      = 0x00100380,    /*    32: 0x00100380 - 0x0010039F */
    FLASH_DF_BLOCK_29      = 0x001003A0,    /*    32: 0x001003A0 - 0x001003BF */
    FLASH_DF_BLOCK_30      = 0x001003C0,    /*    32: 0x001003C0 - 0x001003DF */
    FLASH_DF_BLOCK_31      = 0x001003E0,    /*    32: 0x001003E0 - 0x001003FF */
    FLASH_DF_BLOCK_32      = 0x00100400,    /*    32: 0x00100400 - 0x0010041F */
    FLASH_DF_BLOCK_33      = 0x00100420,    /*    32: 0x00100420 - 0x0010043F */
    FLASH_DF_BLOCK_34      = 0x00100440,    /*    32: 0x00100440 - 0x0010045F */
    FLASH_DF_BLOCK_35      = 0x00100460,    /*    32: 0x00100460 - 0x0010047F */
    FLASH_DF_BLOCK_36      = 0x00100480,    /*    32: 0x00100480 - 0x0010049F */
    FLASH_DF_BLOCK_37      = 0x001004A0,    /*    32: 0x001004A0 - 0x001004BF */
    FLASH_DF_BLOCK_38      = 0x001004C0,    /*    32: 0x001004C0 - 0x001004DF */
    FLASH_DF_BLOCK_39      = 0x001004E0,    /*    32: 0x001004E0 - 0x001004FF */
    FLASH_DF_BLOCK_40      = 0x00100500,    /*    32: 0x00100500 - 0x0010051F */
    FLASH_DF_BLOCK_41      = 0x00100520,    /*    32: 0x00100520 - 0x0010053F */
    FLASH_DF_BLOCK_42      = 0x00100540,    /*    32: 0x00100540 - 0x0010055F */
    FLASH_DF_BLOCK_43      = 0x00100560,    /*    32: 0x00100560 - 0x0010057F */
    FLASH_DF_BLOCK_44      = 0x00100580,    /*    32: 0x00100580 - 0x0010059F */
    FLASH_DF_BLOCK_45      = 0x001005A0,    /*    32: 0x001005A0 - 0x001005BF */
    FLASH_DF_BLOCK_46      = 0x001005C0,    /*    32: 0x001005C0 - 0x001005DF */
    FLASH_DF_BLOCK_47      = 0x001005E0,    /*    32: 0x001005E0 - 0x001005FF */
    FLASH_DF_BLOCK_48      = 0x00100600,    /*    32: 0x00100600 - 0x0010061F */
    FLASH_DF_BLOCK_49      = 0x00100620,    /*    32: 0x00100620 - 0x0010063F */
    FLASH_DF_BLOCK_50      = 0x00100640,    /*    32: 0x00100640 - 0x0010065F */
    FLASH_DF_BLOCK_51      = 0x00100660,    /*    32: 0x00100660 - 0x0010067F */
    FLASH_DF_BLOCK_52      = 0x00100680,    /*    32: 0x00100680 - 0x0010069F */
    FLASH_DF_BLOCK_53      = 0x001006A0,    /*    32: 0x001006A0 - 0x001006BF */
    FLASH_DF_BLOCK_54      = 0x001006C0,    /*    32: 0x001006C0 - 0x001006DF */
    FLASH_DF_BLOCK_55      = 0x001006E0,    /*    32: 0x001006E0 - 0x001006FF */
    FLASH_DF_BLOCK_56      = 0x00100700,    /*    32: 0x00100700 - 0x0010071F */
    FLASH_DF_BLOCK_57      = 0x00100720,    /*    32: 0x00100720 - 0x0010073F */
    FLASH_DF_BLOCK_58      = 0x00100740,    /*    32: 0x00100740 - 0x0010075F */
    FLASH_DF_BLOCK_59      = 0x00100760,    /*    32: 0x00100760 - 0x0010077F */
    FLASH_DF_BLOCK_60      = 0x00100780,    /*    32: 0x00100780 - 0x0010079F */
    FLASH_DF_BLOCK_61      = 0x001007A0,    /*    32: 0x001007A0 - 0x001007BF */
    FLASH_DF_BLOCK_62      = 0x001007C0,    /*    32: 0x001007C0 - 0x001007DF */
    FLASH_DF_BLOCK_63      = 0x001007E0,    /*    32: 0x001007E0 - 0x001007FF */
    FLASH_DF_BLOCK_64      = 0x00100800,    /*    32: 0x00100800 - 0x0010081F */
    FLASH_DF_BLOCK_65      = 0x00100820,    /*    32: 0x00100820 - 0x0010083F */
    FLASH_DF_BLOCK_66      = 0x00100840,    /*    32: 0x00100840 - 0x0010085F */
    FLASH_DF_BLOCK_67      = 0x00100860,    /*    32: 0x00100860 - 0x0010087F */
    FLASH_DF_BLOCK_68      = 0x00100880,    /*    32: 0x00100880 - 0x0010089F */
    FLASH_DF_BLOCK_69      = 0x001008A0,    /*    32: 0x001008A0 - 0x001008BF */
    FLASH_DF_BLOCK_70      = 0x001008C0,    /*    32: 0x001008C0 - 0x001008DF */
    FLASH_DF_BLOCK_71      = 0x001008E0,    /*    32: 0x001008E0 - 0x001008FF */
    FLASH_DF_BLOCK_72      = 0x00100900,    /*    32: 0x00100900 - 0x0010091F */
    FLASH_DF_BLOCK_73      = 0x00100920,    /*    32: 0x00100920 - 0x0010093F */
    FLASH_DF_BLOCK_74      = 0x00100940,    /*    32: 0x00100940 - 0x0010095F */
    FLASH_DF_BLOCK_75      = 0x00100960,    /*    32: 0x00100960 - 0x0010097F */
    FLASH_DF_BLOCK_76      = 0x00100980,    /*    32: 0x00100980 - 0x0010099F */
    FLASH_DF_BLOCK_77      = 0x001009A0,    /*    32: 0x001009A0 - 0x001009BF */
    FLASH_DF_BLOCK_78      = 0x001009C0,    /*    32: 0x001009C0 - 0x001009DF */
    FLASH_DF_BLOCK_79      = 0x001009E0,    /*    32: 0x001009E0 - 0x001009FF */
    FLASH_DF_BLOCK_80      = 0x00100A00,    /*    32: 0x00100A00 - 0x00100A1F */
    FLASH_DF_BLOCK_81      = 0x00100A20,    /*    32: 0x00100A20 - 0x00100A3F */
    FLASH_DF_BLOCK_82      = 0x00100A40,    /*    32: 0x00100A40 - 0x00100A5F */
    FLASH_DF_BLOCK_83      = 0x00100A60,    /*    32: 0x00100A60 - 0x00100A7F */
    FLASH_DF_BLOCK_84      = 0x00100A80,    /*    32: 0x00100A80 - 0x00100A9F */
    FLASH_DF_BLOCK_85      = 0x00100AA0,    /*    32: 0x00100AA0 - 0x00100ABF */
    FLASH_DF_BLOCK_86      = 0x00100AC0,    /*    32: 0x00100AC0 - 0x00100ADF */
    FLASH_DF_BLOCK_87      = 0x00100AE0,    /*    32: 0x00100AE0 - 0x00100AFF */
    FLASH_DF_BLOCK_88      = 0x00100B00,    /*    32: 0x00100B00 - 0x00100B1F */
    FLASH_DF_BLOCK_89      = 0x00100B20,    /*    32: 0x00100B20 - 0x00100B3F */
    FLASH_DF_BLOCK_90      = 0x00100B40,    /*    32: 0x00100B40 - 0x00100B5F */
    FLASH_DF_BLOCK_91      = 0x00100B60,    /*    32: 0x00100B60 - 0x00100B7F */
    FLASH_DF_BLOCK_92      = 0x00100B80,    /*    32: 0x00100B80 - 0x00100B9F */
    FLASH_DF_BLOCK_93      = 0x00100BA0,    /*    32: 0x00100BA0 - 0x00100BBF */
    FLASH_DF_BLOCK_94      = 0x00100BC0,    /*    32: 0x00100BC0 - 0x00100BDF */
    FLASH_DF_BLOCK_95      = 0x00100BE0,    /*    32: 0x00100BE0 - 0x00100BFF */
    FLASH_DF_BLOCK_96      = 0x00100C00,    /*    32: 0x00100C00 - 0x00100C1F */
    FLASH_DF_BLOCK_97      = 0x00100C20,    /*    32: 0x00100C20 - 0x00100C3F */
    FLASH_DF_BLOCK_98      = 0x00100C40,    /*    32: 0x00100C40 - 0x00100C5F */
    FLASH_DF_BLOCK_99      = 0x00100C60,    /*    32: 0x00100C60 - 0x00100C7F */
    FLASH_DF_BLOCK_100     = 0x00100C80,    /*    32: 0x00100C80 - 0x00100C9F */
    FLASH_DF_BLOCK_101     = 0x00100CA0,    /*    32: 0x00100CA0 - 0x00100CBF */
    FLASH_DF_BLOCK_102     = 0x00100CC0,    /*    32: 0x00100CC0 - 0x00100CDF */
    FLASH_DF_BLOCK_103     = 0x00100CE0,    /*    32: 0x00100CE0 - 0x00100CFF */
    FLASH_DF_BLOCK_104     = 0x00100D00,    /*    32: 0x00100D00 - 0x00100D1F */
    FLASH_DF_BLOCK_105     = 0x00100D20,    /*    32: 0x00100D20 - 0x00100D3F */
    FLASH_DF_BLOCK_106     = 0x00100D40,    /*    32: 0x00100D40 - 0x00100D5F */
    FLASH_DF_BLOCK_107     = 0x00100D60,    /*    32: 0x00100D60 - 0x00100D7F */
    FLASH_DF_BLOCK_108     = 0x00100D80,    /*    32: 0x00100D80 - 0x00100D9F */
    FLASH_DF_BLOCK_109     = 0x00100DA0,    /*    32: 0x00100DA0 - 0x00100DBF */
    FLASH_DF_BLOCK_110     = 0x00100DC0,    /*    32: 0x00100DC0 - 0x00100DDF */
    FLASH_DF_BLOCK_111     = 0x00100DE0,    /*    32: 0x00100DE0 - 0x00100DFF */
    FLASH_DF_BLOCK_112     = 0x00100E00,    /*    32: 0x00100E00 - 0x00100E1F */
    FLASH_DF_BLOCK_113     = 0x00100E20,    /*    32: 0x00100E20 - 0x00100E3F */
    FLASH_DF_BLOCK_114     = 0x00100E40,    /*    32: 0x00100E40 - 0x00100E5F */
    FLASH_DF_BLOCK_115     = 0x00100E60,    /*    32: 0x00100E60 - 0x00100E7F */
    FLASH_DF_BLOCK_116     = 0x00100E80,    /*    32: 0x00100E80 - 0x00100E9F */
    FLASH_DF_BLOCK_117     = 0x00100EA0,    /*    32: 0x00100EA0 - 0x00100EBF */
    FLASH_DF_BLOCK_118     = 0x00100EC0,    /*    32: 0x00100EC0 - 0x00100EDF */
    FLASH_DF_BLOCK_119     = 0x00100EE0,    /*    32: 0x00100EE0 - 0x00100EFF */
    FLASH_DF_BLOCK_120     = 0x00100F00,    /*    32: 0x00100F00 - 0x00100F1F */
    FLASH_DF_BLOCK_121     = 0x00100F20,    /*    32: 0x00100F20 - 0x00100F3F */
    FLASH_DF_BLOCK_122     = 0x00100F40,    /*    32: 0x00100F40 - 0x00100F5F */
    FLASH_DF_BLOCK_123     = 0x00100F60,    /*    32: 0x00100F60 - 0x00100F7F */
    FLASH_DF_BLOCK_124     = 0x00100F80,    /*    32: 0x00100F80 - 0x00100F9F */
    FLASH_DF_BLOCK_125     = 0x00100FA0,    /*    32: 0x00100FA0 - 0x00100FBF */
    FLASH_DF_BLOCK_126     = 0x00100FC0,    /*    32: 0x00100FC0 - 0x00100FDF */
    FLASH_DF_BLOCK_127     = 0x00100FE0,    /*    32: 0x00100FE0 - 0x00100FFF */
    FLASH_DF_BLOCK_128     = 0x00101000,    /*    32: 0x00101000 - 0x0010101F */
    FLASH_DF_BLOCK_129     = 0x00101020,    /*    32: 0x00101020 - 0x0010103F */
    FLASH_DF_BLOCK_130     = 0x00101040,    /*    32: 0x00101040 - 0x0010105F */
    FLASH_DF_BLOCK_131     = 0x00101060,    /*    32: 0x00101060 - 0x0010107F */
    FLASH_DF_BLOCK_132     = 0x00101080,    /*    32: 0x00101080 - 0x0010109F */
    FLASH_DF_BLOCK_133     = 0x001010A0,    /*    32: 0x001010A0 - 0x001010BF */
    FLASH_DF_BLOCK_134     = 0x001010C0,    /*    32: 0x001010C0 - 0x001010DF */
    FLASH_DF_BLOCK_135     = 0x001010E0,    /*    32: 0x001010E0 - 0x001010FF */
    FLASH_DF_BLOCK_136     = 0x00101100,    /*    32: 0x00101100 - 0x0010111F */
    FLASH_DF_BLOCK_137     = 0x00101120,    /*    32: 0x00101120 - 0x0010113F */
    FLASH_DF_BLOCK_138     = 0x00101140,    /*    32: 0x00101140 - 0x0010115F */
    FLASH_DF_BLOCK_139     = 0x00101160,    /*    32: 0x00101160 - 0x0010117F */
    FLASH_DF_BLOCK_140     = 0x00101180,    /*    32: 0x00101180 - 0x0010119F */
    FLASH_DF_BLOCK_141     = 0x001011A0,    /*    32: 0x001011A0 - 0x001011BF */
    FLASH_DF_BLOCK_142     = 0x001011C0,    /*    32: 0x001011C0 - 0x001011DF */
    FLASH_DF_BLOCK_143     = 0x001011E0,    /*    32: 0x001011E0 - 0x001011FF */
    FLASH_DF_BLOCK_144     = 0x00101200,    /*    32: 0x00101200 - 0x0010121F */
    FLASH_DF_BLOCK_145     = 0x00101220,    /*    32: 0x00101220 - 0x0010123F */
    FLASH_DF_BLOCK_146     = 0x00101240,    /*    32: 0x00101240 - 0x0010125F */
    FLASH_DF_BLOCK_147     = 0x00101260,    /*    32: 0x00101260 - 0x0010127F */
    FLASH_DF_BLOCK_148     = 0x00101280,    /*    32: 0x00101280 - 0x0010129F */
    FLASH_DF_BLOCK_149     = 0x001012A0,    /*    32: 0x001012A0 - 0x001012BF */
    FLASH_DF_BLOCK_150     = 0x001012C0,    /*    32: 0x001012C0 - 0x001012DF */
    FLASH_DF_BLOCK_151     = 0x001012E0,    /*    32: 0x001012E0 - 0x001012FF */
    FLASH_DF_BLOCK_152     = 0x00101300,    /*    32: 0x00101300 - 0x0010131F */
    FLASH_DF_BLOCK_153     = 0x00101320,    /*    32: 0x00101320 - 0x0010133F */
    FLASH_DF_BLOCK_154     = 0x00101340,    /*    32: 0x00101340 - 0x0010135F */
    FLASH_DF_BLOCK_155     = 0x00101360,    /*    32: 0x00101360 - 0x0010137F */
    FLASH_DF_BLOCK_156     = 0x00101380,    /*    32: 0x00101380 - 0x0010139F */
    FLASH_DF_BLOCK_157     = 0x001013A0,    /*    32: 0x001013A0 - 0x001013BF */
    FLASH_DF_BLOCK_158     = 0x001013C0,    /*    32: 0x001013C0 - 0x001013DF */
    FLASH_DF_BLOCK_159     = 0x001013E0,    /*    32: 0x001013E0 - 0x001013FF */
    FLASH_DF_BLOCK_160     = 0x00101400,    /*    32: 0x00101400 - 0x0010141F */
    FLASH_DF_BLOCK_161     = 0x00101420,    /*    32: 0x00101420 - 0x0010143F */
    FLASH_DF_BLOCK_162     = 0x00101440,    /*    32: 0x00101440 - 0x0010145F */
    FLASH_DF_BLOCK_163     = 0x00101460,    /*    32: 0x00101460 - 0x0010147F */
    FLASH_DF_BLOCK_164     = 0x00101480,    /*    32: 0x00101480 - 0x0010149F */
    FLASH_DF_BLOCK_165     = 0x001014A0,    /*    32: 0x001014A0 - 0x001014BF */
    FLASH_DF_BLOCK_166     = 0x001014C0,    /*    32: 0x001014C0 - 0x001014DF */
    FLASH_DF_BLOCK_167     = 0x001014E0,    /*    32: 0x001014E0 - 0x001014FF */
    FLASH_DF_BLOCK_168     = 0x00101500,    /*    32: 0x00101500 - 0x0010151F */
    FLASH_DF_BLOCK_169     = 0x00101520,    /*    32: 0x00101520 - 0x0010153F */
    FLASH_DF_BLOCK_170     = 0x00101540,    /*    32: 0x00101540 - 0x0010155F */
    FLASH_DF_BLOCK_171     = 0x00101560,    /*    32: 0x00101560 - 0x0010157F */
    FLASH_DF_BLOCK_172     = 0x00101580,    /*    32: 0x00101580 - 0x0010159F */
    FLASH_DF_BLOCK_173     = 0x001015A0,    /*    32: 0x001015A0 - 0x001015BF */
    FLASH_DF_BLOCK_174     = 0x001015C0,    /*    32: 0x001015C0 - 0x001015DF */
    FLASH_DF_BLOCK_175     = 0x001015E0,    /*    32: 0x001015E0 - 0x001015FF */
    FLASH_DF_BLOCK_176     = 0x00101600,    /*    32: 0x00101600 - 0x0010161F */
    FLASH_DF_BLOCK_177     = 0x00101620,    /*    32: 0x00101620 - 0x0010163F */
    FLASH_DF_BLOCK_178     = 0x00101640,    /*    32: 0x00101640 - 0x0010165F */
    FLASH_DF_BLOCK_179     = 0x00101660,    /*    32: 0x00101660 - 0x0010167F */
    FLASH_DF_BLOCK_180     = 0x00101680,    /*    32: 0x00101680 - 0x0010169F */
    FLASH_DF_BLOCK_181     = 0x001016A0,    /*    32: 0x001016A0 - 0x001016BF */
    FLASH_DF_BLOCK_182     = 0x001016C0,    /*    32: 0x001016C0 - 0x001016DF */
    FLASH_DF_BLOCK_183     = 0x001016E0,    /*    32: 0x001016E0 - 0x001016FF */
    FLASH_DF_BLOCK_184     = 0x00101700,    /*    32: 0x00101700 - 0x0010171F */
    FLASH_DF_BLOCK_185     = 0x00101720,    /*    32: 0x00101720 - 0x0010173F */
    FLASH_DF_BLOCK_186     = 0x00101740,    /*    32: 0x00101740 - 0x0010175F */
    FLASH_DF_BLOCK_187     = 0x00101760,    /*    32: 0x00101760 - 0x0010177F */
    FLASH_DF_BLOCK_188     = 0x00101780,    /*    32: 0x00101780 - 0x0010179F */
    FLASH_DF_BLOCK_189     = 0x001017A0,    /*    32: 0x001017A0 - 0x001017BF */
    FLASH_DF_BLOCK_190     = 0x001017C0,    /*    32: 0x001017C0 - 0x001017DF */
    FLASH_DF_BLOCK_191     = 0x001017E0,    /*    32: 0x001017E0 - 0x001017FF */
    FLASH_DF_BLOCK_192     = 0x00101800,    /*    32: 0x00101800 - 0x0010181F */
    FLASH_DF_BLOCK_193     = 0x00101820,    /*    32: 0x00101820 - 0x0010183F */
    FLASH_DF_BLOCK_194     = 0x00101840,    /*    32: 0x00101840 - 0x0010185F */
    FLASH_DF_BLOCK_195     = 0x00101860,    /*    32: 0x00101860 - 0x0010187F */
    FLASH_DF_BLOCK_196     = 0x00101880,    /*    32: 0x00101880 - 0x0010189F */
    FLASH_DF_BLOCK_197     = 0x001018A0,    /*    32: 0x001018A0 - 0x001018BF */
    FLASH_DF_BLOCK_198     = 0x001018C0,    /*    32: 0x001018C0 - 0x001018DF */
    FLASH_DF_BLOCK_199     = 0x001018E0,    /*    32: 0x001018E0 - 0x001018FF */
    FLASH_DF_BLOCK_200     = 0x00101900,    /*    32: 0x00101900 - 0x0010191F */
    FLASH_DF_BLOCK_201     = 0x00101920,    /*    32: 0x00101920 - 0x0010193F */
    FLASH_DF_BLOCK_202     = 0x00101940,    /*    32: 0x00101940 - 0x0010195F */
    FLASH_DF_BLOCK_203     = 0x00101960,    /*    32: 0x00101960 - 0x0010197F */
    FLASH_DF_BLOCK_204     = 0x00101980,    /*    32: 0x00101980 - 0x0010199F */
    FLASH_DF_BLOCK_205     = 0x001019A0,    /*    32: 0x001019A0 - 0x001019BF */
    FLASH_DF_BLOCK_206     = 0x001019C0,    /*    32: 0x001019C0 - 0x001019DF */
    FLASH_DF_BLOCK_207     = 0x001019E0,    /*    32: 0x001019E0 - 0x001019FF */
    FLASH_DF_BLOCK_208     = 0x00101A00,    /*    32: 0x00101A00 - 0x00101A1F */
    FLASH_DF_BLOCK_209     = 0x00101A20,    /*    32: 0x00101A20 - 0x00101A3F */
    FLASH_DF_BLOCK_210     = 0x00101A40,    /*    32: 0x00101A40 - 0x00101A5F */
    FLASH_DF_BLOCK_211     = 0x00101A60,    /*    32: 0x00101A60 - 0x00101A7F */
    FLASH_DF_BLOCK_212     = 0x00101A80,    /*    32: 0x00101A80 - 0x00101A9F */
    FLASH_DF_BLOCK_213     = 0x00101AA0,    /*    32: 0x00101AA0 - 0x00101ABF */
    FLASH_DF_BLOCK_214     = 0x00101AC0,    /*    32: 0x00101AC0 - 0x00101ADF */
    FLASH_DF_BLOCK_215     = 0x00101AE0,    /*    32: 0x00101AE0 - 0x00101AFF */
    FLASH_DF_BLOCK_216     = 0x00101B00,    /*    32: 0x00101B00 - 0x00101B1F */
    FLASH_DF_BLOCK_217     = 0x00101B20,    /*    32: 0x00101B20 - 0x00101B3F */
    FLASH_DF_BLOCK_218     = 0x00101B40,    /*    32: 0x00101B40 - 0x00101B5F */
    FLASH_DF_BLOCK_219     = 0x00101B60,    /*    32: 0x00101B60 - 0x00101B7F */
    FLASH_DF_BLOCK_220     = 0x00101B80,    /*    32: 0x00101B80 - 0x00101B9F */
    FLASH_DF_BLOCK_221     = 0x00101BA0,    /*    32: 0x00101BA0 - 0x00101BBF */
    FLASH_DF_BLOCK_222     = 0x00101BC0,    /*    32: 0x00101BC0 - 0x00101BDF */
    FLASH_DF_BLOCK_223     = 0x00101BE0,    /*    32: 0x00101BE0 - 0x00101BFF */
    FLASH_DF_BLOCK_224     = 0x00101C00,    /*    32: 0x00101C00 - 0x00101C1F */
    FLASH_DF_BLOCK_225     = 0x00101C20,    /*    32: 0x00101C20 - 0x00101C3F */
    FLASH_DF_BLOCK_226     = 0x00101C40,    /*    32: 0x00101C40 - 0x00101C5F */
    FLASH_DF_BLOCK_227     = 0x00101C60,    /*    32: 0x00101C60 - 0x00101C7F */
    FLASH_DF_BLOCK_228     = 0x00101C80,    /*    32: 0x00101C80 - 0x00101C9F */
    FLASH_DF_BLOCK_229     = 0x00101CA0,    /*    32: 0x00101CA0 - 0x00101CBF */
    FLASH_DF_BLOCK_230     = 0x00101CC0,    /*    32: 0x00101CC0 - 0x00101CDF */
    FLASH_DF_BLOCK_231     = 0x00101CE0,    /*    32: 0x00101CE0 - 0x00101CFF */
    FLASH_DF_BLOCK_232     = 0x00101D00,    /*    32: 0x00101D00 - 0x00101D1F */
    FLASH_DF_BLOCK_233     = 0x00101D20,    /*    32: 0x00101D20 - 0x00101D3F */
    FLASH_DF_BLOCK_234     = 0x00101D40,    /*    32: 0x00101D40 - 0x00101D5F */
    FLASH_DF_BLOCK_235     = 0x00101D60,    /*    32: 0x00101D60 - 0x00101D7F */
    FLASH_DF_BLOCK_236     = 0x00101D80,    /*    32: 0x00101D80 - 0x00101D9F */
    FLASH_DF_BLOCK_237     = 0x00101DA0,    /*    32: 0x00101DA0 - 0x00101DBF */
    FLASH_DF_BLOCK_238     = 0x00101DC0,    /*    32: 0x00101DC0 - 0x00101DDF */
    FLASH_DF_BLOCK_239     = 0x00101DE0,    /*    32: 0x00101DE0 - 0x00101DFF */
    FLASH_DF_BLOCK_240     = 0x00101E00,    /*    32: 0x00101E00 - 0x00101E1F */
    FLASH_DF_BLOCK_241     = 0x00101E20,    /*    32: 0x00101E20 - 0x00101E3F */
    FLASH_DF_BLOCK_242     = 0x00101E40,    /*    32: 0x00101E40 - 0x00101E5F */
    FLASH_DF_BLOCK_243     = 0x00101E60,    /*    32: 0x00101E60 - 0x00101E7F */
    FLASH_DF_BLOCK_244     = 0x00101E80,    /*    32: 0x00101E80 - 0x00101E9F */
    FLASH_DF_BLOCK_245     = 0x00101EA0,    /*    32: 0x00101EA0 - 0x00101EBF */
    FLASH_DF_BLOCK_246     = 0x00101EC0,    /*    32: 0x00101EC0 - 0x00101EDF */
    FLASH_DF_BLOCK_247     = 0x00101EE0,    /*    32: 0x00101EE0 - 0x00101EFF */
    FLASH_DF_BLOCK_248     = 0x00101F00,    /*    32: 0x00101F00 - 0x00101F1F */
    FLASH_DF_BLOCK_249     = 0x00101F20,    /*    32: 0x00101F20 - 0x00101F3F */
    FLASH_DF_BLOCK_250     = 0x00101F40,    /*    32: 0x00101F40 - 0x00101F5F */
    FLASH_DF_BLOCK_251     = 0x00101F60,    /*    32: 0x00101F60 - 0x00101F7F */
    FLASH_DF_BLOCK_252     = 0x00101F80,    /*    32: 0x00101F80 - 0x00101F9F */
    FLASH_DF_BLOCK_253     = 0x00101FA0,    /*    32: 0x00101FA0 - 0x00101FBF */
    FLASH_DF_BLOCK_254     = 0x00101FC0,    /*    32: 0x00101FC0 - 0x00101FDF */
    FLASH_DF_BLOCK_255     = 0x00101FE0,    /*    32: 0x00101FE0 - 0x00101FFF */
    FLASH_DF_BLOCK_256     = 0x00102000,    /*    32: 0x00102000 - 0x0010201F */
    FLASH_DF_BLOCK_257     = 0x00102020,    /*    32: 0x00102020 - 0x0010203F */
    FLASH_DF_BLOCK_258     = 0x00102040,    /*    32: 0x00102040 - 0x0010205F */
    FLASH_DF_BLOCK_259     = 0x00102060,    /*    32: 0x00102060 - 0x0010207F */
    FLASH_DF_BLOCK_260     = 0x00102080,    /*    32: 0x00102080 - 0x0010209F */
    FLASH_DF_BLOCK_261     = 0x001020A0,    /*    32: 0x001020A0 - 0x001020BF */
    FLASH_DF_BLOCK_262     = 0x001020C0,    /*    32: 0x001020C0 - 0x001020DF */
    FLASH_DF_BLOCK_263     = 0x001020E0,    /*    32: 0x001020E0 - 0x001020FF */
    FLASH_DF_BLOCK_264     = 0x00102100,    /*    32: 0x00102100 - 0x0010211F */
    FLASH_DF_BLOCK_265     = 0x00102120,    /*    32: 0x00102120 - 0x0010213F */
    FLASH_DF_BLOCK_266     = 0x00102140,    /*    32: 0x00102140 - 0x0010215F */
    FLASH_DF_BLOCK_267     = 0x00102160,    /*    32: 0x00102160 - 0x0010217F */
    FLASH_DF_BLOCK_268     = 0x00102180,    /*    32: 0x00102180 - 0x0010219F */
    FLASH_DF_BLOCK_269     = 0x001021A0,    /*    32: 0x001021A0 - 0x001021BF */
    FLASH_DF_BLOCK_270     = 0x001021C0,    /*    32: 0x001021C0 - 0x001021DF */
    FLASH_DF_BLOCK_271     = 0x001021E0,    /*    32: 0x001021E0 - 0x001021FF */
    FLASH_DF_BLOCK_272     = 0x00102200,    /*    32: 0x00102200 - 0x0010221F */
    FLASH_DF_BLOCK_273     = 0x00102220,    /*    32: 0x00102220 - 0x0010223F */
    FLASH_DF_BLOCK_274     = 0x00102240,    /*    32: 0x00102240 - 0x0010225F */
    FLASH_DF_BLOCK_275     = 0x00102260,    /*    32: 0x00102260 - 0x0010227F */
    FLASH_DF_BLOCK_276     = 0x00102280,    /*    32: 0x00102280 - 0x0010229F */
    FLASH_DF_BLOCK_277     = 0x001022A0,    /*    32: 0x001022A0 - 0x001022BF */
    FLASH_DF_BLOCK_278     = 0x001022C0,    /*    32: 0x001022C0 - 0x001022DF */
    FLASH_DF_BLOCK_279     = 0x001022E0,    /*    32: 0x001022E0 - 0x001022FF */
    FLASH_DF_BLOCK_280     = 0x00102300,    /*    32: 0x00102300 - 0x0010231F */
    FLASH_DF_BLOCK_281     = 0x00102320,    /*    32: 0x00102320 - 0x0010233F */
    FLASH_DF_BLOCK_282     = 0x00102340,    /*    32: 0x00102340 - 0x0010235F */
    FLASH_DF_BLOCK_283     = 0x00102360,    /*    32: 0x00102360 - 0x0010237F */
    FLASH_DF_BLOCK_284     = 0x00102380,    /*    32: 0x00102380 - 0x0010239F */
    FLASH_DF_BLOCK_285     = 0x001023A0,    /*    32: 0x001023A0 - 0x001023BF */
    FLASH_DF_BLOCK_286     = 0x001023C0,    /*    32: 0x001023C0 - 0x001023DF */
    FLASH_DF_BLOCK_287     = 0x001023E0,    /*    32: 0x001023E0 - 0x001023FF */
    FLASH_DF_BLOCK_288     = 0x00102400,    /*    32: 0x00102400 - 0x0010241F */
    FLASH_DF_BLOCK_289     = 0x00102420,    /*    32: 0x00102420 - 0x0010243F */
    FLASH_DF_BLOCK_290     = 0x00102440,    /*    32: 0x00102440 - 0x0010245F */
    FLASH_DF_BLOCK_291     = 0x00102460,    /*    32: 0x00102460 - 0x0010247F */
    FLASH_DF_BLOCK_292     = 0x00102480,    /*    32: 0x00102480 - 0x0010249F */
    FLASH_DF_BLOCK_293     = 0x001024A0,    /*    32: 0x001024A0 - 0x001024BF */
    FLASH_DF_BLOCK_294     = 0x001024C0,    /*    32: 0x001024C0 - 0x001024DF */
    FLASH_DF_BLOCK_295     = 0x001024E0,    /*    32: 0x001024E0 - 0x001024FF */
    FLASH_DF_BLOCK_296     = 0x00102500,    /*    32: 0x00102500 - 0x0010251F */
    FLASH_DF_BLOCK_297     = 0x00102520,    /*    32: 0x00102520 - 0x0010253F */
    FLASH_DF_BLOCK_298     = 0x00102540,    /*    32: 0x00102540 - 0x0010255F */
    FLASH_DF_BLOCK_299     = 0x00102560,    /*    32: 0x00102560 - 0x0010257F */
    FLASH_DF_BLOCK_300     = 0x00102580,    /*    32: 0x00102580 - 0x0010259F */
    FLASH_DF_BLOCK_301     = 0x001025A0,    /*    32: 0x001025A0 - 0x001025BF */
    FLASH_DF_BLOCK_302     = 0x001025C0,    /*    32: 0x001025C0 - 0x001025DF */
    FLASH_DF_BLOCK_303     = 0x001025E0,    /*    32: 0x001025E0 - 0x001025FF */
    FLASH_DF_BLOCK_304     = 0x00102600,    /*    32: 0x00102600 - 0x0010261F */
    FLASH_DF_BLOCK_305     = 0x00102620,    /*    32: 0x00102620 - 0x0010263F */
    FLASH_DF_BLOCK_306     = 0x00102640,    /*    32: 0x00102640 - 0x0010265F */
    FLASH_DF_BLOCK_307     = 0x00102660,    /*    32: 0x00102660 - 0x0010267F */
    FLASH_DF_BLOCK_308     = 0x00102680,    /*    32: 0x00102680 - 0x0010269F */
    FLASH_DF_BLOCK_309     = 0x001026A0,    /*    32: 0x001026A0 - 0x001026BF */
    FLASH_DF_BLOCK_310     = 0x001026C0,    /*    32: 0x001026C0 - 0x001026DF */
    FLASH_DF_BLOCK_311     = 0x001026E0,    /*    32: 0x001026E0 - 0x001026FF */
    FLASH_DF_BLOCK_312     = 0x00102700,    /*    32: 0x00102700 - 0x0010271F */
    FLASH_DF_BLOCK_313     = 0x00102720,    /*    32: 0x00102720 - 0x0010273F */
    FLASH_DF_BLOCK_314     = 0x00102740,    /*    32: 0x00102740 - 0x0010275F */
    FLASH_DF_BLOCK_315     = 0x00102760,    /*    32: 0x00102760 - 0x0010277F */
    FLASH_DF_BLOCK_316     = 0x00102780,    /*    32: 0x00102780 - 0x0010279F */
    FLASH_DF_BLOCK_317     = 0x001027A0,    /*    32: 0x001027A0 - 0x001027BF */
    FLASH_DF_BLOCK_318     = 0x001027C0,    /*    32: 0x001027C0 - 0x001027DF */
    FLASH_DF_BLOCK_319     = 0x001027E0,    /*    32: 0x001027E0 - 0x001027FF */
    FLASH_DF_BLOCK_320     = 0x00102800,    /*    32: 0x00102800 - 0x0010281F */
    FLASH_DF_BLOCK_321     = 0x00102820,    /*    32: 0x00102820 - 0x0010283F */
    FLASH_DF_BLOCK_322     = 0x00102840,    /*    32: 0x00102840 - 0x0010285F */
    FLASH_DF_BLOCK_323     = 0x00102860,    /*    32: 0x00102860 - 0x0010287F */
    FLASH_DF_BLOCK_324     = 0x00102880,    /*    32: 0x00102880 - 0x0010289F */
    FLASH_DF_BLOCK_325     = 0x001028A0,    /*    32: 0x001028A0 - 0x001028BF */
    FLASH_DF_BLOCK_326     = 0x001028C0,    /*    32: 0x001028C0 - 0x001028DF */
    FLASH_DF_BLOCK_327     = 0x001028E0,    /*    32: 0x001028E0 - 0x001028FF */
    FLASH_DF_BLOCK_328     = 0x00102900,    /*    32: 0x00102900 - 0x0010291F */
    FLASH_DF_BLOCK_329     = 0x00102920,    /*    32: 0x00102920 - 0x0010293F */
    FLASH_DF_BLOCK_330     = 0x00102940,    /*    32: 0x00102940 - 0x0010295F */
    FLASH_DF_BLOCK_331     = 0x00102960,    /*    32: 0x00102960 - 0x0010297F */
    FLASH_DF_BLOCK_332     = 0x00102980,    /*    32: 0x00102980 - 0x0010299F */
    FLASH_DF_BLOCK_333     = 0x001029A0,    /*    32: 0x001029A0 - 0x001029BF */
    FLASH_DF_BLOCK_334     = 0x001029C0,    /*    32: 0x001029C0 - 0x001029DF */
    FLASH_DF_BLOCK_335     = 0x001029E0,    /*    32: 0x001029E0 - 0x001029FF */
    FLASH_DF_BLOCK_336     = 0x00102A00,    /*    32: 0x00102A00 - 0x00102A1F */
    FLASH_DF_BLOCK_337     = 0x00102A20,    /*    32: 0x00102A20 - 0x00102A3F */
    FLASH_DF_BLOCK_338     = 0x00102A40,    /*    32: 0x00102A40 - 0x00102A5F */
    FLASH_DF_BLOCK_339     = 0x00102A60,    /*    32: 0x00102A60 - 0x00102A7F */
    FLASH_DF_BLOCK_340     = 0x00102A80,    /*    32: 0x00102A80 - 0x00102A9F */
    FLASH_DF_BLOCK_341     = 0x00102AA0,    /*    32: 0x00102AA0 - 0x00102ABF */
    FLASH_DF_BLOCK_342     = 0x00102AC0,    /*    32: 0x00102AC0 - 0x00102ADF */
    FLASH_DF_BLOCK_343     = 0x00102AE0,    /*    32: 0x00102AE0 - 0x00102AFF */
    FLASH_DF_BLOCK_344     = 0x00102B00,    /*    32: 0x00102B00 - 0x00102B1F */
    FLASH_DF_BLOCK_345     = 0x00102B20,    /*    32: 0x00102B20 - 0x00102B3F */
    FLASH_DF_BLOCK_346     = 0x00102B40,    /*    32: 0x00102B40 - 0x00102B5F */
    FLASH_DF_BLOCK_347     = 0x00102B60,    /*    32: 0x00102B60 - 0x00102B7F */
    FLASH_DF_BLOCK_348     = 0x00102B80,    /*    32: 0x00102B80 - 0x00102B9F */
    FLASH_DF_BLOCK_349     = 0x00102BA0,    /*    32: 0x00102BA0 - 0x00102BBF */
    FLASH_DF_BLOCK_350     = 0x00102BC0,    /*    32: 0x00102BC0 - 0x00102BDF */
    FLASH_DF_BLOCK_351     = 0x00102BE0,    /*    32: 0x00102BE0 - 0x00102BFF */
    FLASH_DF_BLOCK_352     = 0x00102C00,    /*    32: 0x00102C00 - 0x00102C1F */
    FLASH_DF_BLOCK_353     = 0x00102C20,    /*    32: 0x00102C20 - 0x00102C3F */
    FLASH_DF_BLOCK_354     = 0x00102C40,    /*    32: 0x00102C40 - 0x00102C5F */
    FLASH_DF_BLOCK_355     = 0x00102C60,    /*    32: 0x00102C60 - 0x00102C7F */
    FLASH_DF_BLOCK_356     = 0x00102C80,    /*    32: 0x00102C80 - 0x00102C9F */
    FLASH_DF_BLOCK_357     = 0x00102CA0,    /*    32: 0x00102CA0 - 0x00102CBF */
    FLASH_DF_BLOCK_358     = 0x00102CC0,    /*    32: 0x00102CC0 - 0x00102CDF */
    FLASH_DF_BLOCK_359     = 0x00102CE0,    /*    32: 0x00102CE0 - 0x00102CFF */
    FLASH_DF_BLOCK_360     = 0x00102D00,    /*    32: 0x00102D00 - 0x00102D1F */
    FLASH_DF_BLOCK_361     = 0x00102D20,    /*    32: 0x00102D20 - 0x00102D3F */
    FLASH_DF_BLOCK_362     = 0x00102D40,    /*    32: 0x00102D40 - 0x00102D5F */
    FLASH_DF_BLOCK_363     = 0x00102D60,    /*    32: 0x00102D60 - 0x00102D7F */
    FLASH_DF_BLOCK_364     = 0x00102D80,    /*    32: 0x00102D80 - 0x00102D9F */
    FLASH_DF_BLOCK_365     = 0x00102DA0,    /*    32: 0x00102DA0 - 0x00102DBF */
    FLASH_DF_BLOCK_366     = 0x00102DC0,    /*    32: 0x00102DC0 - 0x00102DDF */
    FLASH_DF_BLOCK_367     = 0x00102DE0,    /*    32: 0x00102DE0 - 0x00102DFF */
    FLASH_DF_BLOCK_368     = 0x00102E00,    /*    32: 0x00102E00 - 0x00102E1F */
    FLASH_DF_BLOCK_369     = 0x00102E20,    /*    32: 0x00102E20 - 0x00102E3F */
    FLASH_DF_BLOCK_370     = 0x00102E40,    /*    32: 0x00102E40 - 0x00102E5F */
    FLASH_DF_BLOCK_371     = 0x00102E60,    /*    32: 0x00102E60 - 0x00102E7F */
    FLASH_DF_BLOCK_372     = 0x00102E80,    /*    32: 0x00102E80 - 0x00102E9F */
    FLASH_DF_BLOCK_373     = 0x00102EA0,    /*    32: 0x00102EA0 - 0x00102EBF */
    FLASH_DF_BLOCK_374     = 0x00102EC0,    /*    32: 0x00102EC0 - 0x00102EDF */
    FLASH_DF_BLOCK_375     = 0x00102EE0,    /*    32: 0x00102EE0 - 0x00102EFF */
    FLASH_DF_BLOCK_376     = 0x00102F00,    /*    32: 0x00102F00 - 0x00102F1F */
    FLASH_DF_BLOCK_377     = 0x00102F20,    /*    32: 0x00102F20 - 0x00102F3F */
    FLASH_DF_BLOCK_378     = 0x00102F40,    /*    32: 0x00102F40 - 0x00102F5F */
    FLASH_DF_BLOCK_379     = 0x00102F60,    /*    32: 0x00102F60 - 0x00102F7F */
    FLASH_DF_BLOCK_380     = 0x00102F80,    /*    32: 0x00102F80 - 0x00102F9F */
    FLASH_DF_BLOCK_381     = 0x00102FA0,    /*    32: 0x00102FA0 - 0x00102FBF */
    FLASH_DF_BLOCK_382     = 0x00102FC0,    /*    32: 0x00102FC0 - 0x00102FDF */
    FLASH_DF_BLOCK_383     = 0x00102FE0,    /*    32: 0x00102FE0 - 0x00102FFF */
    FLASH_DF_BLOCK_384     = 0x00103000,    /*    32: 0x00103000 - 0x0010301F */
    FLASH_DF_BLOCK_385     = 0x00103020,    /*    32: 0x00103020 - 0x0010303F */
    FLASH_DF_BLOCK_386     = 0x00103040,    /*    32: 0x00103040 - 0x0010305F */
    FLASH_DF_BLOCK_387     = 0x00103060,    /*    32: 0x00103060 - 0x0010307F */
    FLASH_DF_BLOCK_388     = 0x00103080,    /*    32: 0x00103080 - 0x0010309F */
    FLASH_DF_BLOCK_389     = 0x001030A0,    /*    32: 0x001030A0 - 0x001030BF */
    FLASH_DF_BLOCK_390     = 0x001030C0,    /*    32: 0x001030C0 - 0x001030DF */
    FLASH_DF_BLOCK_391     = 0x001030E0,    /*    32: 0x001030E0 - 0x001030FF */
    FLASH_DF_BLOCK_392     = 0x00103100,    /*    32: 0x00103100 - 0x0010311F */
    FLASH_DF_BLOCK_393     = 0x00103120,    /*    32: 0x00103120 - 0x0010313F */
    FLASH_DF_BLOCK_394     = 0x00103140,    /*    32: 0x00103140 - 0x0010315F */
    FLASH_DF_BLOCK_395     = 0x00103160,    /*    32: 0x00103160 - 0x0010317F */
    FLASH_DF_BLOCK_396     = 0x00103180,    /*    32: 0x00103180 - 0x0010319F */
    FLASH_DF_BLOCK_397     = 0x001031A0,    /*    32: 0x001031A0 - 0x001031BF */
    FLASH_DF_BLOCK_398     = 0x001031C0,    /*    32: 0x001031C0 - 0x001031DF */
    FLASH_DF_BLOCK_399     = 0x001031E0,    /*    32: 0x001031E0 - 0x001031FF */
    FLASH_DF_BLOCK_400     = 0x00103200,    /*    32: 0x00103200 - 0x0010321F */
    FLASH_DF_BLOCK_401     = 0x00103220,    /*    32: 0x00103220 - 0x0010323F */
    FLASH_DF_BLOCK_402     = 0x00103240,    /*    32: 0x00103240 - 0x0010325F */
    FLASH_DF_BLOCK_403     = 0x00103260,    /*    32: 0x00103260 - 0x0010327F */
    FLASH_DF_BLOCK_404     = 0x00103280,    /*    32: 0x00103280 - 0x0010329F */
    FLASH_DF_BLOCK_405     = 0x001032A0,    /*    32: 0x001032A0 - 0x001032BF */
    FLASH_DF_BLOCK_406     = 0x001032C0,    /*    32: 0x001032C0 - 0x001032DF */
    FLASH_DF_BLOCK_407     = 0x001032E0,    /*    32: 0x001032E0 - 0x001032FF */
    FLASH_DF_BLOCK_408     = 0x00103300,    /*    32: 0x00103300 - 0x0010331F */
    FLASH_DF_BLOCK_409     = 0x00103320,    /*    32: 0x00103320 - 0x0010333F */
    FLASH_DF_BLOCK_410     = 0x00103340,    /*    32: 0x00103340 - 0x0010335F */
    FLASH_DF_BLOCK_411     = 0x00103360,    /*    32: 0x00103360 - 0x0010337F */
    FLASH_DF_BLOCK_412     = 0x00103380,    /*    32: 0x00103380 - 0x0010339F */
    FLASH_DF_BLOCK_413     = 0x001033A0,    /*    32: 0x001033A0 - 0x001033BF */
    FLASH_DF_BLOCK_414     = 0x001033C0,    /*    32: 0x001033C0 - 0x001033DF */
    FLASH_DF_BLOCK_415     = 0x001033E0,    /*    32: 0x001033E0 - 0x001033FF */
    FLASH_DF_BLOCK_416     = 0x00103400,    /*    32: 0x00103400 - 0x0010341F */
    FLASH_DF_BLOCK_417     = 0x00103420,    /*    32: 0x00103420 - 0x0010343F */
    FLASH_DF_BLOCK_418     = 0x00103440,    /*    32: 0x00103440 - 0x0010345F */
    FLASH_DF_BLOCK_419     = 0x00103460,    /*    32: 0x00103460 - 0x0010347F */
    FLASH_DF_BLOCK_420     = 0x00103480,    /*    32: 0x00103480 - 0x0010349F */
    FLASH_DF_BLOCK_421     = 0x001034A0,    /*    32: 0x001034A0 - 0x001034BF */
    FLASH_DF_BLOCK_422     = 0x001034C0,    /*    32: 0x001034C0 - 0x001034DF */
    FLASH_DF_BLOCK_423     = 0x001034E0,    /*    32: 0x001034E0 - 0x001034FF */
    FLASH_DF_BLOCK_424     = 0x00103500,    /*    32: 0x00103500 - 0x0010351F */
    FLASH_DF_BLOCK_425     = 0x00103520,    /*    32: 0x00103520 - 0x0010353F */
    FLASH_DF_BLOCK_426     = 0x00103540,    /*    32: 0x00103540 - 0x0010355F */
    FLASH_DF_BLOCK_427     = 0x00103560,    /*    32: 0x00103560 - 0x0010357F */
    FLASH_DF_BLOCK_428     = 0x00103580,    /*    32: 0x00103580 - 0x0010359F */
    FLASH_DF_BLOCK_429     = 0x001035A0,    /*    32: 0x001035A0 - 0x001035BF */
    FLASH_DF_BLOCK_430     = 0x001035C0,    /*    32: 0x001035C0 - 0x001035DF */
    FLASH_DF_BLOCK_431     = 0x001035E0,    /*    32: 0x001035E0 - 0x001035FF */
    FLASH_DF_BLOCK_432     = 0x00103600,    /*    32: 0x00103600 - 0x0010361F */
    FLASH_DF_BLOCK_433     = 0x00103620,    /*    32: 0x00103620 - 0x0010363F */
    FLASH_DF_BLOCK_434     = 0x00103640,    /*    32: 0x00103640 - 0x0010365F */
    FLASH_DF_BLOCK_435     = 0x00103660,    /*    32: 0x00103660 - 0x0010367F */
    FLASH_DF_BLOCK_436     = 0x00103680,    /*    32: 0x00103680 - 0x0010369F */
    FLASH_DF_BLOCK_437     = 0x001036A0,    /*    32: 0x001036A0 - 0x001036BF */
    FLASH_DF_BLOCK_438     = 0x001036C0,    /*    32: 0x001036C0 - 0x001036DF */
    FLASH_DF_BLOCK_439     = 0x001036E0,    /*    32: 0x001036E0 - 0x001036FF */
    FLASH_DF_BLOCK_440     = 0x00103700,    /*    32: 0x00103700 - 0x0010371F */
    FLASH_DF_BLOCK_441     = 0x00103720,    /*    32: 0x00103720 - 0x0010373F */
    FLASH_DF_BLOCK_442     = 0x00103740,    /*    32: 0x00103740 - 0x0010375F */
    FLASH_DF_BLOCK_443     = 0x00103760,    /*    32: 0x00103760 - 0x0010377F */
    FLASH_DF_BLOCK_444     = 0x00103780,    /*    32: 0x00103780 - 0x0010379F */
    FLASH_DF_BLOCK_445     = 0x001037A0,    /*    32: 0x001037A0 - 0x001037BF */
    FLASH_DF_BLOCK_446     = 0x001037C0,    /*    32: 0x001037C0 - 0x001037DF */
    FLASH_DF_BLOCK_447     = 0x001037E0,    /*    32: 0x001037E0 - 0x001037FF */
    FLASH_DF_BLOCK_448     = 0x00103800,    /*    32: 0x00103800 - 0x0010381F */
    FLASH_DF_BLOCK_449     = 0x00103820,    /*    32: 0x00103820 - 0x0010383F */
    FLASH_DF_BLOCK_450     = 0x00103840,    /*    32: 0x00103840 - 0x0010385F */
    FLASH_DF_BLOCK_451     = 0x00103860,    /*    32: 0x00103860 - 0x0010387F */
    FLASH_DF_BLOCK_452     = 0x00103880,    /*    32: 0x00103880 - 0x0010389F */
    FLASH_DF_BLOCK_453     = 0x001038A0,    /*    32: 0x001038A0 - 0x001038BF */
    FLASH_DF_BLOCK_454     = 0x001038C0,    /*    32: 0x001038C0 - 0x001038DF */
    FLASH_DF_BLOCK_455     = 0x001038E0,    /*    32: 0x001038E0 - 0x001038FF */
    FLASH_DF_BLOCK_456     = 0x00103900,    /*    32: 0x00103900 - 0x0010391F */
    FLASH_DF_BLOCK_457     = 0x00103920,    /*    32: 0x00103920 - 0x0010393F */
    FLASH_DF_BLOCK_458     = 0x00103940,    /*    32: 0x00103940 - 0x0010395F */
    FLASH_DF_BLOCK_459     = 0x00103960,    /*    32: 0x00103960 - 0x0010397F */
    FLASH_DF_BLOCK_460     = 0x00103980,    /*    32: 0x00103980 - 0x0010399F */
    FLASH_DF_BLOCK_461     = 0x001039A0,    /*    32: 0x001039A0 - 0x001039BF */
    FLASH_DF_BLOCK_462     = 0x001039C0,    /*    32: 0x001039C0 - 0x001039DF */
    FLASH_DF_BLOCK_463     = 0x001039E0,    /*    32: 0x001039E0 - 0x001039FF */
    FLASH_DF_BLOCK_464     = 0x00103A00,    /*    32: 0x00103A00 - 0x00103A1F */
    FLASH_DF_BLOCK_465     = 0x00103A20,    /*    32: 0x00103A20 - 0x00103A3F */
    FLASH_DF_BLOCK_466     = 0x00103A40,    /*    32: 0x00103A40 - 0x00103A5F */
    FLASH_DF_BLOCK_467     = 0x00103A60,    /*    32: 0x00103A60 - 0x00103A7F */
    FLASH_DF_BLOCK_468     = 0x00103A80,    /*    32: 0x00103A80 - 0x00103A9F */
    FLASH_DF_BLOCK_469     = 0x00103AA0,    /*    32: 0x00103AA0 - 0x00103ABF */
    FLASH_DF_BLOCK_470     = 0x00103AC0,    /*    32: 0x00103AC0 - 0x00103ADF */
    FLASH_DF_BLOCK_471     = 0x00103AE0,    /*    32: 0x00103AE0 - 0x00103AFF */
    FLASH_DF_BLOCK_472     = 0x00103B00,    /*    32: 0x00103B00 - 0x00103B1F */
    FLASH_DF_BLOCK_473     = 0x00103B20,    /*    32: 0x00103B20 - 0x00103B3F */
    FLASH_DF_BLOCK_474     = 0x00103B40,    /*    32: 0x00103B40 - 0x00103B5F */
    FLASH_DF_BLOCK_475     = 0x00103B60,    /*    32: 0x00103B60 - 0x00103B7F */
    FLASH_DF_BLOCK_476     = 0x00103B80,    /*    32: 0x00103B80 - 0x00103B9F */
    FLASH_DF_BLOCK_477     = 0x00103BA0,    /*    32: 0x00103BA0 - 0x00103BBF */
    FLASH_DF_BLOCK_478     = 0x00103BC0,    /*    32: 0x00103BC0 - 0x00103BDF */
    FLASH_DF_BLOCK_479     = 0x00103BE0,    /*    32: 0x00103BE0 - 0x00103BFF */
    FLASH_DF_BLOCK_480     = 0x00103C00,    /*    32: 0x00103C00 - 0x00103C1F */
    FLASH_DF_BLOCK_481     = 0x00103C20,    /*    32: 0x00103C20 - 0x00103C3F */
    FLASH_DF_BLOCK_482     = 0x00103C40,    /*    32: 0x00103C40 - 0x00103C5F */
    FLASH_DF_BLOCK_483     = 0x00103C60,    /*    32: 0x00103C60 - 0x00103C7F */
    FLASH_DF_BLOCK_484     = 0x00103C80,    /*    32: 0x00103C80 - 0x00103C9F */
    FLASH_DF_BLOCK_485     = 0x00103CA0,    /*    32: 0x00103CA0 - 0x00103CBF */
    FLASH_DF_BLOCK_486     = 0x00103CC0,    /*    32: 0x00103CC0 - 0x00103CDF */
    FLASH_DF_BLOCK_487     = 0x00103CE0,    /*    32: 0x00103CE0 - 0x00103CFF */
    FLASH_DF_BLOCK_488     = 0x00103D00,    /*    32: 0x00103D00 - 0x00103D1F */
    FLASH_DF_BLOCK_489     = 0x00103D20,    /*    32: 0x00103D20 - 0x00103D3F */
    FLASH_DF_BLOCK_490     = 0x00103D40,    /*    32: 0x00103D40 - 0x00103D5F */
    FLASH_DF_BLOCK_491     = 0x00103D60,    /*    32: 0x00103D60 - 0x00103D7F */
    FLASH_DF_BLOCK_492     = 0x00103D80,    /*    32: 0x00103D80 - 0x00103D9F */
    FLASH_DF_BLOCK_493     = 0x00103DA0,    /*    32: 0x00103DA0 - 0x00103DBF */
    FLASH_DF_BLOCK_494     = 0x00103DC0,    /*    32: 0x00103DC0 - 0x00103DDF */
    FLASH_DF_BLOCK_495     = 0x00103DE0,    /*    32: 0x00103DE0 - 0x00103DFF */
    FLASH_DF_BLOCK_496     = 0x00103E00,    /*    32: 0x00103E00 - 0x00103E1F */
    FLASH_DF_BLOCK_497     = 0x00103E20,    /*    32: 0x00103E20 - 0x00103E3F */
    FLASH_DF_BLOCK_498     = 0x00103E40,    /*    32: 0x00103E40 - 0x00103E5F */
    FLASH_DF_BLOCK_499     = 0x00103E60,    /*    32: 0x00103E60 - 0x00103E7F */
    FLASH_DF_BLOCK_500     = 0x00103E80,    /*    32: 0x00103E80 - 0x00103E9F */
    FLASH_DF_BLOCK_501     = 0x00103EA0,    /*    32: 0x00103EA0 - 0x00103EBF */
    FLASH_DF_BLOCK_502     = 0x00103EC0,    /*    32: 0x00103EC0 - 0x00103EDF */
    FLASH_DF_BLOCK_503     = 0x00103EE0,    /*    32: 0x00103EE0 - 0x00103EFF */
    FLASH_DF_BLOCK_504     = 0x00103F00,    /*    32: 0x00103F00 - 0x00103F1F */
    FLASH_DF_BLOCK_505     = 0x00103F20,    /*    32: 0x00103F20 - 0x00103F3F */
    FLASH_DF_BLOCK_506     = 0x00103F40,    /*    32: 0x00103F40 - 0x00103F5F */
    FLASH_DF_BLOCK_507     = 0x00103F60,    /*    32: 0x00103F60 - 0x00103F7F */
    FLASH_DF_BLOCK_508     = 0x00103F80,    /*    32: 0x00103F80 - 0x00103F9F */
    FLASH_DF_BLOCK_509     = 0x00103FA0,    /*    32: 0x00103FA0 - 0x00103FBF */
    FLASH_DF_BLOCK_510     = 0x00103FC0,    /*    32: 0x00103FC0 - 0x00103FDF */
    FLASH_DF_BLOCK_511     = 0x00103FE0,    /*    32: 0x00103FE0 - 0x00103FFF */
    FLASH_DF_BLOCK_512     = 0x00104000,    /*    32: 0x00104000 - 0x0010401F */
    FLASH_DF_BLOCK_513     = 0x00104020,    /*    32: 0x00104020 - 0x0010403F */
    FLASH_DF_BLOCK_514     = 0x00104040,    /*    32: 0x00104040 - 0x0010405F */
    FLASH_DF_BLOCK_515     = 0x00104060,    /*    32: 0x00104060 - 0x0010407F */
    FLASH_DF_BLOCK_516     = 0x00104080,    /*    32: 0x00104080 - 0x0010409F */
    FLASH_DF_BLOCK_517     = 0x001040A0,    /*    32: 0x001040A0 - 0x001040BF */
    FLASH_DF_BLOCK_518     = 0x001040C0,    /*    32: 0x001040C0 - 0x001040DF */
    FLASH_DF_BLOCK_519     = 0x001040E0,    /*    32: 0x001040E0 - 0x001040FF */
    FLASH_DF_BLOCK_520     = 0x00104100,    /*    32: 0x00104100 - 0x0010411F */
    FLASH_DF_BLOCK_521     = 0x00104120,    /*    32: 0x00104120 - 0x0010413F */
    FLASH_DF_BLOCK_522     = 0x00104140,    /*    32: 0x00104140 - 0x0010415F */
    FLASH_DF_BLOCK_523     = 0x00104160,    /*    32: 0x00104160 - 0x0010417F */
    FLASH_DF_BLOCK_524     = 0x00104180,    /*    32: 0x00104180 - 0x0010419F */
    FLASH_DF_BLOCK_525     = 0x001041A0,    /*    32: 0x001041A0 - 0x001041BF */
    FLASH_DF_BLOCK_526     = 0x001041C0,    /*    32: 0x001041C0 - 0x001041DF */
    FLASH_DF_BLOCK_527     = 0x001041E0,    /*    32: 0x001041E0 - 0x001041FF */
    FLASH_DF_BLOCK_528     = 0x00104200,    /*    32: 0x00104200 - 0x0010421F */
    FLASH_DF_BLOCK_529     = 0x00104220,    /*    32: 0x00104220 - 0x0010423F */
    FLASH_DF_BLOCK_530     = 0x00104240,    /*    32: 0x00104240 - 0x0010425F */
    FLASH_DF_BLOCK_531     = 0x00104260,    /*    32: 0x00104260 - 0x0010427F */
    FLASH_DF_BLOCK_532     = 0x00104280,    /*    32: 0x00104280 - 0x0010429F */
    FLASH_DF_BLOCK_533     = 0x001042A0,    /*    32: 0x001042A0 - 0x001042BF */
    FLASH_DF_BLOCK_534     = 0x001042C0,    /*    32: 0x001042C0 - 0x001042DF */
    FLASH_DF_BLOCK_535     = 0x001042E0,    /*    32: 0x001042E0 - 0x001042FF */
    FLASH_DF_BLOCK_536     = 0x00104300,    /*    32: 0x00104300 - 0x0010431F */
    FLASH_DF_BLOCK_537     = 0x00104320,    /*    32: 0x00104320 - 0x0010433F */
    FLASH_DF_BLOCK_538     = 0x00104340,    /*    32: 0x00104340 - 0x0010435F */
    FLASH_DF_BLOCK_539     = 0x00104360,    /*    32: 0x00104360 - 0x0010437F */
    FLASH_DF_BLOCK_540     = 0x00104380,    /*    32: 0x00104380 - 0x0010439F */
    FLASH_DF_BLOCK_541     = 0x001043A0,    /*    32: 0x001043A0 - 0x001043BF */
    FLASH_DF_BLOCK_542     = 0x001043C0,    /*    32: 0x001043C0 - 0x001043DF */
    FLASH_DF_BLOCK_543     = 0x001043E0,    /*    32: 0x001043E0 - 0x001043FF */
    FLASH_DF_BLOCK_544     = 0x00104400,    /*    32: 0x00104400 - 0x0010441F */
    FLASH_DF_BLOCK_545     = 0x00104420,    /*    32: 0x00104420 - 0x0010443F */
    FLASH_DF_BLOCK_546     = 0x00104440,    /*    32: 0x00104440 - 0x0010445F */
    FLASH_DF_BLOCK_547     = 0x00104460,    /*    32: 0x00104460 - 0x0010447F */
    FLASH_DF_BLOCK_548     = 0x00104480,    /*    32: 0x00104480 - 0x0010449F */
    FLASH_DF_BLOCK_549     = 0x001044A0,    /*    32: 0x001044A0 - 0x001044BF */
    FLASH_DF_BLOCK_550     = 0x001044C0,    /*    32: 0x001044C0 - 0x001044DF */
    FLASH_DF_BLOCK_551     = 0x001044E0,    /*    32: 0x001044E0 - 0x001044FF */
    FLASH_DF_BLOCK_552     = 0x00104500,    /*    32: 0x00104500 - 0x0010451F */
    FLASH_DF_BLOCK_553     = 0x00104520,    /*    32: 0x00104520 - 0x0010453F */
    FLASH_DF_BLOCK_554     = 0x00104540,    /*    32: 0x00104540 - 0x0010455F */
    FLASH_DF_BLOCK_555     = 0x00104560,    /*    32: 0x00104560 - 0x0010457F */
    FLASH_DF_BLOCK_556     = 0x00104580,    /*    32: 0x00104580 - 0x0010459F */
    FLASH_DF_BLOCK_557     = 0x001045A0,    /*    32: 0x001045A0 - 0x001045BF */
    FLASH_DF_BLOCK_558     = 0x001045C0,    /*    32: 0x001045C0 - 0x001045DF */
    FLASH_DF_BLOCK_559     = 0x001045E0,    /*    32: 0x001045E0 - 0x001045FF */
    FLASH_DF_BLOCK_560     = 0x00104600,    /*    32: 0x00104600 - 0x0010461F */
    FLASH_DF_BLOCK_561     = 0x00104620,    /*    32: 0x00104620 - 0x0010463F */
    FLASH_DF_BLOCK_562     = 0x00104640,    /*    32: 0x00104640 - 0x0010465F */
    FLASH_DF_BLOCK_563     = 0x00104660,    /*    32: 0x00104660 - 0x0010467F */
    FLASH_DF_BLOCK_564     = 0x00104680,    /*    32: 0x00104680 - 0x0010469F */
    FLASH_DF_BLOCK_565     = 0x001046A0,    /*    32: 0x001046A0 - 0x001046BF */
    FLASH_DF_BLOCK_566     = 0x001046C0,    /*    32: 0x001046C0 - 0x001046DF */
    FLASH_DF_BLOCK_567     = 0x001046E0,    /*    32: 0x001046E0 - 0x001046FF */
    FLASH_DF_BLOCK_568     = 0x00104700,    /*    32: 0x00104700 - 0x0010471F */
    FLASH_DF_BLOCK_569     = 0x00104720,    /*    32: 0x00104720 - 0x0010473F */
    FLASH_DF_BLOCK_570     = 0x00104740,    /*    32: 0x00104740 - 0x0010475F */
    FLASH_DF_BLOCK_571     = 0x00104760,    /*    32: 0x00104760 - 0x0010477F */
    FLASH_DF_BLOCK_572     = 0x00104780,    /*    32: 0x00104780 - 0x0010479F */
    FLASH_DF_BLOCK_573     = 0x001047A0,    /*    32: 0x001047A0 - 0x001047BF */
    FLASH_DF_BLOCK_574     = 0x001047C0,    /*    32: 0x001047C0 - 0x001047DF */
    FLASH_DF_BLOCK_575     = 0x001047E0,    /*    32: 0x001047E0 - 0x001047FF */
    FLASH_DF_BLOCK_576     = 0x00104800,    /*    32: 0x00104800 - 0x0010481F */
    FLASH_DF_BLOCK_577     = 0x00104820,    /*    32: 0x00104820 - 0x0010483F */
    FLASH_DF_BLOCK_578     = 0x00104840,    /*    32: 0x00104840 - 0x0010485F */
    FLASH_DF_BLOCK_579     = 0x00104860,    /*    32: 0x00104860 - 0x0010487F */
    FLASH_DF_BLOCK_580     = 0x00104880,    /*    32: 0x00104880 - 0x0010489F */
    FLASH_DF_BLOCK_581     = 0x001048A0,    /*    32: 0x001048A0 - 0x001048BF */
    FLASH_DF_BLOCK_582     = 0x001048C0,    /*    32: 0x001048C0 - 0x001048DF */
    FLASH_DF_BLOCK_583     = 0x001048E0,    /*    32: 0x001048E0 - 0x001048FF */
    FLASH_DF_BLOCK_584     = 0x00104900,    /*    32: 0x00104900 - 0x0010491F */
    FLASH_DF_BLOCK_585     = 0x00104920,    /*    32: 0x00104920 - 0x0010493F */
    FLASH_DF_BLOCK_586     = 0x00104940,    /*    32: 0x00104940 - 0x0010495F */
    FLASH_DF_BLOCK_587     = 0x00104960,    /*    32: 0x00104960 - 0x0010497F */
    FLASH_DF_BLOCK_588     = 0x00104980,    /*    32: 0x00104980 - 0x0010499F */
    FLASH_DF_BLOCK_589     = 0x001049A0,    /*    32: 0x001049A0 - 0x001049BF */
    FLASH_DF_BLOCK_590     = 0x001049C0,    /*    32: 0x001049C0 - 0x001049DF */
    FLASH_DF_BLOCK_591     = 0x001049E0,    /*    32: 0x001049E0 - 0x001049FF */
    FLASH_DF_BLOCK_592     = 0x00104A00,    /*    32: 0x00104A00 - 0x00104A1F */
    FLASH_DF_BLOCK_593     = 0x00104A20,    /*    32: 0x00104A20 - 0x00104A3F */
    FLASH_DF_BLOCK_594     = 0x00104A40,    /*    32: 0x00104A40 - 0x00104A5F */
    FLASH_DF_BLOCK_595     = 0x00104A60,    /*    32: 0x00104A60 - 0x00104A7F */
    FLASH_DF_BLOCK_596     = 0x00104A80,    /*    32: 0x00104A80 - 0x00104A9F */
    FLASH_DF_BLOCK_597     = 0x00104AA0,    /*    32: 0x00104AA0 - 0x00104ABF */
    FLASH_DF_BLOCK_598     = 0x00104AC0,    /*    32: 0x00104AC0 - 0x00104ADF */
    FLASH_DF_BLOCK_599     = 0x00104AE0,    /*    32: 0x00104AE0 - 0x00104AFF */
    FLASH_DF_BLOCK_600     = 0x00104B00,    /*    32: 0x00104B00 - 0x00104B1F */
    FLASH_DF_BLOCK_601     = 0x00104B20,    /*    32: 0x00104B20 - 0x00104B3F */
    FLASH_DF_BLOCK_602     = 0x00104B40,    /*    32: 0x00104B40 - 0x00104B5F */
    FLASH_DF_BLOCK_603     = 0x00104B60,    /*    32: 0x00104B60 - 0x00104B7F */
    FLASH_DF_BLOCK_604     = 0x00104B80,    /*    32: 0x00104B80 - 0x00104B9F */
    FLASH_DF_BLOCK_605     = 0x00104BA0,    /*    32: 0x00104BA0 - 0x00104BBF */
    FLASH_DF_BLOCK_606     = 0x00104BC0,    /*    32: 0x00104BC0 - 0x00104BDF */
    FLASH_DF_BLOCK_607     = 0x00104BE0,    /*    32: 0x00104BE0 - 0x00104BFF */
    FLASH_DF_BLOCK_608     = 0x00104C00,    /*    32: 0x00104C00 - 0x00104C1F */
    FLASH_DF_BLOCK_609     = 0x00104C20,    /*    32: 0x00104C20 - 0x00104C3F */
    FLASH_DF_BLOCK_610     = 0x00104C40,    /*    32: 0x00104C40 - 0x00104C5F */
    FLASH_DF_BLOCK_611     = 0x00104C60,    /*    32: 0x00104C60 - 0x00104C7F */
    FLASH_DF_BLOCK_612     = 0x00104C80,    /*    32: 0x00104C80 - 0x00104C9F */
    FLASH_DF_BLOCK_613     = 0x00104CA0,    /*    32: 0x00104CA0 - 0x00104CBF */
    FLASH_DF_BLOCK_614     = 0x00104CC0,    /*    32: 0x00104CC0 - 0x00104CDF */
    FLASH_DF_BLOCK_615     = 0x00104CE0,    /*    32: 0x00104CE0 - 0x00104CFF */
    FLASH_DF_BLOCK_616     = 0x00104D00,    /*    32: 0x00104D00 - 0x00104D1F */
    FLASH_DF_BLOCK_617     = 0x00104D20,    /*    32: 0x00104D20 - 0x00104D3F */
    FLASH_DF_BLOCK_618     = 0x00104D40,    /*    32: 0x00104D40 - 0x00104D5F */
    FLASH_DF_BLOCK_619     = 0x00104D60,    /*    32: 0x00104D60 - 0x00104D7F */
    FLASH_DF_BLOCK_620     = 0x00104D80,    /*    32: 0x00104D80 - 0x00104D9F */
    FLASH_DF_BLOCK_621     = 0x00104DA0,    /*    32: 0x00104DA0 - 0x00104DBF */
    FLASH_DF_BLOCK_622     = 0x00104DC0,    /*    32: 0x00104DC0 - 0x00104DDF */
    FLASH_DF_BLOCK_623     = 0x00104DE0,    /*    32: 0x00104DE0 - 0x00104DFF */
    FLASH_DF_BLOCK_624     = 0x00104E00,    /*    32: 0x00104E00 - 0x00104E1F */
    FLASH_DF_BLOCK_625     = 0x00104E20,    /*    32: 0x00104E20 - 0x00104E3F */
    FLASH_DF_BLOCK_626     = 0x00104E40,    /*    32: 0x00104E40 - 0x00104E5F */
    FLASH_DF_BLOCK_627     = 0x00104E60,    /*    32: 0x00104E60 - 0x00104E7F */
    FLASH_DF_BLOCK_628     = 0x00104E80,    /*    32: 0x00104E80 - 0x00104E9F */
    FLASH_DF_BLOCK_629     = 0x00104EA0,    /*    32: 0x00104EA0 - 0x00104EBF */
    FLASH_DF_BLOCK_630     = 0x00104EC0,    /*    32: 0x00104EC0 - 0x00104EDF */
    FLASH_DF_BLOCK_631     = 0x00104EE0,    /*    32: 0x00104EE0 - 0x00104EFF */
    FLASH_DF_BLOCK_632     = 0x00104F00,    /*    32: 0x00104F00 - 0x00104F1F */
    FLASH_DF_BLOCK_633     = 0x00104F20,    /*    32: 0x00104F20 - 0x00104F3F */
    FLASH_DF_BLOCK_634     = 0x00104F40,    /*    32: 0x00104F40 - 0x00104F5F */
    FLASH_DF_BLOCK_635     = 0x00104F60,    /*    32: 0x00104F60 - 0x00104F7F */
    FLASH_DF_BLOCK_636     = 0x00104F80,    /*    32: 0x00104F80 - 0x00104F9F */
    FLASH_DF_BLOCK_637     = 0x00104FA0,    /*    32: 0x00104FA0 - 0x00104FBF */
    FLASH_DF_BLOCK_638     = 0x00104FC0,    /*    32: 0x00104FC0 - 0x00104FDF */
    FLASH_DF_BLOCK_639     = 0x00104FE0,    /*    32: 0x00104FE0 - 0x00104FFF */
    FLASH_DF_BLOCK_640     = 0x00105000,    /*    32: 0x00105000 - 0x0010501F */
    FLASH_DF_BLOCK_641     = 0x00105020,    /*    32: 0x00105020 - 0x0010503F */
    FLASH_DF_BLOCK_642     = 0x00105040,    /*    32: 0x00105040 - 0x0010505F */
    FLASH_DF_BLOCK_643     = 0x00105060,    /*    32: 0x00105060 - 0x0010507F */
    FLASH_DF_BLOCK_644     = 0x00105080,    /*    32: 0x00105080 - 0x0010509F */
    FLASH_DF_BLOCK_645     = 0x001050A0,    /*    32: 0x001050A0 - 0x001050BF */
    FLASH_DF_BLOCK_646     = 0x001050C0,    /*    32: 0x001050C0 - 0x001050DF */
    FLASH_DF_BLOCK_647     = 0x001050E0,    /*    32: 0x001050E0 - 0x001050FF */
    FLASH_DF_BLOCK_648     = 0x00105100,    /*    32: 0x00105100 - 0x0010511F */
    FLASH_DF_BLOCK_649     = 0x00105120,    /*    32: 0x00105120 - 0x0010513F */
    FLASH_DF_BLOCK_650     = 0x00105140,    /*    32: 0x00105140 - 0x0010515F */
    FLASH_DF_BLOCK_651     = 0x00105160,    /*    32: 0x00105160 - 0x0010517F */
    FLASH_DF_BLOCK_652     = 0x00105180,    /*    32: 0x00105180 - 0x0010519F */
    FLASH_DF_BLOCK_653     = 0x001051A0,    /*    32: 0x001051A0 - 0x001051BF */
    FLASH_DF_BLOCK_654     = 0x001051C0,    /*    32: 0x001051C0 - 0x001051DF */
    FLASH_DF_BLOCK_655     = 0x001051E0,    /*    32: 0x001051E0 - 0x001051FF */
    FLASH_DF_BLOCK_656     = 0x00105200,    /*    32: 0x00105200 - 0x0010521F */
    FLASH_DF_BLOCK_657     = 0x00105220,    /*    32: 0x00105220 - 0x0010523F */
    FLASH_DF_BLOCK_658     = 0x00105240,    /*    32: 0x00105240 - 0x0010525F */
    FLASH_DF_BLOCK_659     = 0x00105260,    /*    32: 0x00105260 - 0x0010527F */
    FLASH_DF_BLOCK_660     = 0x00105280,    /*    32: 0x00105280 - 0x0010529F */
    FLASH_DF_BLOCK_661     = 0x001052A0,    /*    32: 0x001052A0 - 0x001052BF */
    FLASH_DF_BLOCK_662     = 0x001052C0,    /*    32: 0x001052C0 - 0x001052DF */
    FLASH_DF_BLOCK_663     = 0x001052E0,    /*    32: 0x001052E0 - 0x001052FF */
    FLASH_DF_BLOCK_664     = 0x00105300,    /*    32: 0x00105300 - 0x0010531F */
    FLASH_DF_BLOCK_665     = 0x00105320,    /*    32: 0x00105320 - 0x0010533F */
    FLASH_DF_BLOCK_666     = 0x00105340,    /*    32: 0x00105340 - 0x0010535F */
    FLASH_DF_BLOCK_667     = 0x00105360,    /*    32: 0x00105360 - 0x0010537F */
    FLASH_DF_BLOCK_668     = 0x00105380,    /*    32: 0x00105380 - 0x0010539F */
    FLASH_DF_BLOCK_669     = 0x001053A0,    /*    32: 0x001053A0 - 0x001053BF */
    FLASH_DF_BLOCK_670     = 0x001053C0,    /*    32: 0x001053C0 - 0x001053DF */
    FLASH_DF_BLOCK_671     = 0x001053E0,    /*    32: 0x001053E0 - 0x001053FF */
    FLASH_DF_BLOCK_672     = 0x00105400,    /*    32: 0x00105400 - 0x0010541F */
    FLASH_DF_BLOCK_673     = 0x00105420,    /*    32: 0x00105420 - 0x0010543F */
    FLASH_DF_BLOCK_674     = 0x00105440,    /*    32: 0x00105440 - 0x0010545F */
    FLASH_DF_BLOCK_675     = 0x00105460,    /*    32: 0x00105460 - 0x0010547F */
    FLASH_DF_BLOCK_676     = 0x00105480,    /*    32: 0x00105480 - 0x0010549F */
    FLASH_DF_BLOCK_677     = 0x001054A0,    /*    32: 0x001054A0 - 0x001054BF */
    FLASH_DF_BLOCK_678     = 0x001054C0,    /*    32: 0x001054C0 - 0x001054DF */
    FLASH_DF_BLOCK_679     = 0x001054E0,    /*    32: 0x001054E0 - 0x001054FF */
    FLASH_DF_BLOCK_680     = 0x00105500,    /*    32: 0x00105500 - 0x0010551F */
    FLASH_DF_BLOCK_681     = 0x00105520,    /*    32: 0x00105520 - 0x0010553F */
    FLASH_DF_BLOCK_682     = 0x00105540,    /*    32: 0x00105540 - 0x0010555F */
    FLASH_DF_BLOCK_683     = 0x00105560,    /*    32: 0x00105560 - 0x0010557F */
    FLASH_DF_BLOCK_684     = 0x00105580,    /*    32: 0x00105580 - 0x0010559F */
    FLASH_DF_BLOCK_685     = 0x001055A0,    /*    32: 0x001055A0 - 0x001055BF */
    FLASH_DF_BLOCK_686     = 0x001055C0,    /*    32: 0x001055C0 - 0x001055DF */
    FLASH_DF_BLOCK_687     = 0x001055E0,    /*    32: 0x001055E0 - 0x001055FF */
    FLASH_DF_BLOCK_688     = 0x00105600,    /*    32: 0x00105600 - 0x0010561F */
    FLASH_DF_BLOCK_689     = 0x00105620,    /*    32: 0x00105620 - 0x0010563F */
    FLASH_DF_BLOCK_690     = 0x00105640,    /*    32: 0x00105640 - 0x0010565F */
    FLASH_DF_BLOCK_691     = 0x00105660,    /*    32: 0x00105660 - 0x0010567F */
    FLASH_DF_BLOCK_692     = 0x00105680,    /*    32: 0x00105680 - 0x0010569F */
    FLASH_DF_BLOCK_693     = 0x001056A0,    /*    32: 0x001056A0 - 0x001056BF */
    FLASH_DF_BLOCK_694     = 0x001056C0,    /*    32: 0x001056C0 - 0x001056DF */
    FLASH_DF_BLOCK_695     = 0x001056E0,    /*    32: 0x001056E0 - 0x001056FF */
    FLASH_DF_BLOCK_696     = 0x00105700,    /*    32: 0x00105700 - 0x0010571F */
    FLASH_DF_BLOCK_697     = 0x00105720,    /*    32: 0x00105720 - 0x0010573F */
    FLASH_DF_BLOCK_698     = 0x00105740,    /*    32: 0x00105740 - 0x0010575F */
    FLASH_DF_BLOCK_699     = 0x00105760,    /*    32: 0x00105760 - 0x0010577F */
    FLASH_DF_BLOCK_700     = 0x00105780,    /*    32: 0x00105780 - 0x0010579F */
    FLASH_DF_BLOCK_701     = 0x001057A0,    /*    32: 0x001057A0 - 0x001057BF */
    FLASH_DF_BLOCK_702     = 0x001057C0,    /*    32: 0x001057C0 - 0x001057DF */
    FLASH_DF_BLOCK_703     = 0x001057E0,    /*    32: 0x001057E0 - 0x001057FF */
    FLASH_DF_BLOCK_704     = 0x00105800,    /*    32: 0x00105800 - 0x0010581F */
    FLASH_DF_BLOCK_705     = 0x00105820,    /*    32: 0x00105820 - 0x0010583F */
    FLASH_DF_BLOCK_706     = 0x00105840,    /*    32: 0x00105840 - 0x0010585F */
    FLASH_DF_BLOCK_707     = 0x00105860,    /*    32: 0x00105860 - 0x0010587F */
    FLASH_DF_BLOCK_708     = 0x00105880,    /*    32: 0x00105880 - 0x0010589F */
    FLASH_DF_BLOCK_709     = 0x001058A0,    /*    32: 0x001058A0 - 0x001058BF */
    FLASH_DF_BLOCK_710     = 0x001058C0,    /*    32: 0x001058C0 - 0x001058DF */
    FLASH_DF_BLOCK_711     = 0x001058E0,    /*    32: 0x001058E0 - 0x001058FF */
    FLASH_DF_BLOCK_712     = 0x00105900,    /*    32: 0x00105900 - 0x0010591F */
    FLASH_DF_BLOCK_713     = 0x00105920,    /*    32: 0x00105920 - 0x0010593F */
    FLASH_DF_BLOCK_714     = 0x00105940,    /*    32: 0x00105940 - 0x0010595F */
    FLASH_DF_BLOCK_715     = 0x00105960,    /*    32: 0x00105960 - 0x0010597F */
    FLASH_DF_BLOCK_716     = 0x00105980,    /*    32: 0x00105980 - 0x0010599F */
    FLASH_DF_BLOCK_717     = 0x001059A0,    /*    32: 0x001059A0 - 0x001059BF */
    FLASH_DF_BLOCK_718     = 0x001059C0,    /*    32: 0x001059C0 - 0x001059DF */
    FLASH_DF_BLOCK_719     = 0x001059E0,    /*    32: 0x001059E0 - 0x001059FF */
    FLASH_DF_BLOCK_720     = 0x00105A00,    /*    32: 0x00105A00 - 0x00105A1F */
    FLASH_DF_BLOCK_721     = 0x00105A20,    /*    32: 0x00105A20 - 0x00105A3F */
    FLASH_DF_BLOCK_722     = 0x00105A40,    /*    32: 0x00105A40 - 0x00105A5F */
    FLASH_DF_BLOCK_723     = 0x00105A60,    /*    32: 0x00105A60 - 0x00105A7F */
    FLASH_DF_BLOCK_724     = 0x00105A80,    /*    32: 0x00105A80 - 0x00105A9F */
    FLASH_DF_BLOCK_725     = 0x00105AA0,    /*    32: 0x00105AA0 - 0x00105ABF */
    FLASH_DF_BLOCK_726     = 0x00105AC0,    /*    32: 0x00105AC0 - 0x00105ADF */
    FLASH_DF_BLOCK_727     = 0x00105AE0,    /*    32: 0x00105AE0 - 0x00105AFF */
    FLASH_DF_BLOCK_728     = 0x00105B00,    /*    32: 0x00105B00 - 0x00105B1F */
    FLASH_DF_BLOCK_729     = 0x00105B20,    /*    32: 0x00105B20 - 0x00105B3F */
    FLASH_DF_BLOCK_730     = 0x00105B40,    /*    32: 0x00105B40 - 0x00105B5F */
    FLASH_DF_BLOCK_731     = 0x00105B60,    /*    32: 0x00105B60 - 0x00105B7F */
    FLASH_DF_BLOCK_732     = 0x00105B80,    /*    32: 0x00105B80 - 0x00105B9F */
    FLASH_DF_BLOCK_733     = 0x00105BA0,    /*    32: 0x00105BA0 - 0x00105BBF */
    FLASH_DF_BLOCK_734     = 0x00105BC0,    /*    32: 0x00105BC0 - 0x00105BDF */
    FLASH_DF_BLOCK_735     = 0x00105BE0,    /*    32: 0x00105BE0 - 0x00105BFF */
    FLASH_DF_BLOCK_736     = 0x00105C00,    /*    32: 0x00105C00 - 0x00105C1F */
    FLASH_DF_BLOCK_737     = 0x00105C20,    /*    32: 0x00105C20 - 0x00105C3F */
    FLASH_DF_BLOCK_738     = 0x00105C40,    /*    32: 0x00105C40 - 0x00105C5F */
    FLASH_DF_BLOCK_739     = 0x00105C60,    /*    32: 0x00105C60 - 0x00105C7F */
    FLASH_DF_BLOCK_740     = 0x00105C80,    /*    32: 0x00105C80 - 0x00105C9F */
    FLASH_DF_BLOCK_741     = 0x00105CA0,    /*    32: 0x00105CA0 - 0x00105CBF */
    FLASH_DF_BLOCK_742     = 0x00105CC0,    /*    32: 0x00105CC0 - 0x00105CDF */
    FLASH_DF_BLOCK_743     = 0x00105CE0,    /*    32: 0x00105CE0 - 0x00105CFF */
    FLASH_DF_BLOCK_744     = 0x00105D00,    /*    32: 0x00105D00 - 0x00105D1F */
    FLASH_DF_BLOCK_745     = 0x00105D20,    /*    32: 0x00105D20 - 0x00105D3F */
    FLASH_DF_BLOCK_746     = 0x00105D40,    /*    32: 0x00105D40 - 0x00105D5F */
    FLASH_DF_BLOCK_747     = 0x00105D60,    /*    32: 0x00105D60 - 0x00105D7F */
    FLASH_DF_BLOCK_748     = 0x00105D80,    /*    32: 0x00105D80 - 0x00105D9F */
    FLASH_DF_BLOCK_749     = 0x00105DA0,    /*    32: 0x00105DA0 - 0x00105DBF */
    FLASH_DF_BLOCK_750     = 0x00105DC0,    /*    32: 0x00105DC0 - 0x00105DDF */
    FLASH_DF_BLOCK_751     = 0x00105DE0,    /*    32: 0x00105DE0 - 0x00105DFF */
    FLASH_DF_BLOCK_752     = 0x00105E00,    /*    32: 0x00105E00 - 0x00105E1F */
    FLASH_DF_BLOCK_753     = 0x00105E20,    /*    32: 0x00105E20 - 0x00105E3F */
    FLASH_DF_BLOCK_754     = 0x00105E40,    /*    32: 0x00105E40 - 0x00105E5F */
    FLASH_DF_BLOCK_755     = 0x00105E60,    /*    32: 0x00105E60 - 0x00105E7F */
    FLASH_DF_BLOCK_756     = 0x00105E80,    /*    32: 0x00105E80 - 0x00105E9F */
    FLASH_DF_BLOCK_757     = 0x00105EA0,    /*    32: 0x00105EA0 - 0x00105EBF */
    FLASH_DF_BLOCK_758     = 0x00105EC0,    /*    32: 0x00105EC0 - 0x00105EDF */
    FLASH_DF_BLOCK_759     = 0x00105EE0,    /*    32: 0x00105EE0 - 0x00105EFF */
    FLASH_DF_BLOCK_760     = 0x00105F00,    /*    32: 0x00105F00 - 0x00105F1F */
    FLASH_DF_BLOCK_761     = 0x00105F20,    /*    32: 0x00105F20 - 0x00105F3F */
    FLASH_DF_BLOCK_762     = 0x00105F40,    /*    32: 0x00105F40 - 0x00105F5F */
    FLASH_DF_BLOCK_763     = 0x00105F60,    /*    32: 0x00105F60 - 0x00105F7F */
    FLASH_DF_BLOCK_764     = 0x00105F80,    /*    32: 0x00105F80 - 0x00105F9F */
    FLASH_DF_BLOCK_765     = 0x00105FA0,    /*    32: 0x00105FA0 - 0x00105FBF */
    FLASH_DF_BLOCK_766     = 0x00105FC0,    /*    32: 0x00105FC0 - 0x00105FDF */
    FLASH_DF_BLOCK_767     = 0x00105FE0,    /*    32: 0x00105FE0 - 0x00105FFF */
    FLASH_DF_BLOCK_768     = 0x00106000,    /*    32: 0x00106000 - 0x0010601F */
    FLASH_DF_BLOCK_769     = 0x00106020,    /*    32: 0x00106020 - 0x0010603F */
    FLASH_DF_BLOCK_770     = 0x00106040,    /*    32: 0x00106040 - 0x0010605F */
    FLASH_DF_BLOCK_771     = 0x00106060,    /*    32: 0x00106060 - 0x0010607F */
    FLASH_DF_BLOCK_772     = 0x00106080,    /*    32: 0x00106080 - 0x0010609F */
    FLASH_DF_BLOCK_773     = 0x001060A0,    /*    32: 0x001060A0 - 0x001060BF */
    FLASH_DF_BLOCK_774     = 0x001060C0,    /*    32: 0x001060C0 - 0x001060DF */
    FLASH_DF_BLOCK_775     = 0x001060E0,    /*    32: 0x001060E0 - 0x001060FF */
    FLASH_DF_BLOCK_776     = 0x00106100,    /*    32: 0x00106100 - 0x0010611F */
    FLASH_DF_BLOCK_777     = 0x00106120,    /*    32: 0x00106120 - 0x0010613F */
    FLASH_DF_BLOCK_778     = 0x00106140,    /*    32: 0x00106140 - 0x0010615F */
    FLASH_DF_BLOCK_779     = 0x00106160,    /*    32: 0x00106160 - 0x0010617F */
    FLASH_DF_BLOCK_780     = 0x00106180,    /*    32: 0x00106180 - 0x0010619F */
    FLASH_DF_BLOCK_781     = 0x001061A0,    /*    32: 0x001061A0 - 0x001061BF */
    FLASH_DF_BLOCK_782     = 0x001061C0,    /*    32: 0x001061C0 - 0x001061DF */
    FLASH_DF_BLOCK_783     = 0x001061E0,    /*    32: 0x001061E0 - 0x001061FF */
    FLASH_DF_BLOCK_784     = 0x00106200,    /*    32: 0x00106200 - 0x0010621F */
    FLASH_DF_BLOCK_785     = 0x00106220,    /*    32: 0x00106220 - 0x0010623F */
    FLASH_DF_BLOCK_786     = 0x00106240,    /*    32: 0x00106240 - 0x0010625F */
    FLASH_DF_BLOCK_787     = 0x00106260,    /*    32: 0x00106260 - 0x0010627F */
    FLASH_DF_BLOCK_788     = 0x00106280,    /*    32: 0x00106280 - 0x0010629F */
    FLASH_DF_BLOCK_789     = 0x001062A0,    /*    32: 0x001062A0 - 0x001062BF */
    FLASH_DF_BLOCK_790     = 0x001062C0,    /*    32: 0x001062C0 - 0x001062DF */
    FLASH_DF_BLOCK_791     = 0x001062E0,    /*    32: 0x001062E0 - 0x001062FF */
    FLASH_DF_BLOCK_792     = 0x00106300,    /*    32: 0x00106300 - 0x0010631F */
    FLASH_DF_BLOCK_793     = 0x00106320,    /*    32: 0x00106320 - 0x0010633F */
    FLASH_DF_BLOCK_794     = 0x00106340,    /*    32: 0x00106340 - 0x0010635F */
    FLASH_DF_BLOCK_795     = 0x00106360,    /*    32: 0x00106360 - 0x0010637F */
    FLASH_DF_BLOCK_796     = 0x00106380,    /*    32: 0x00106380 - 0x0010639F */
    FLASH_DF_BLOCK_797     = 0x001063A0,    /*    32: 0x001063A0 - 0x001063BF */
    FLASH_DF_BLOCK_798     = 0x001063C0,    /*    32: 0x001063C0 - 0x001063DF */
    FLASH_DF_BLOCK_799     = 0x001063E0,    /*    32: 0x001063E0 - 0x001063FF */
    FLASH_DF_BLOCK_800     = 0x00106400,    /*    32: 0x00106400 - 0x0010641F */
    FLASH_DF_BLOCK_801     = 0x00106420,    /*    32: 0x00106420 - 0x0010643F */
    FLASH_DF_BLOCK_802     = 0x00106440,    /*    32: 0x00106440 - 0x0010645F */
    FLASH_DF_BLOCK_803     = 0x00106460,    /*    32: 0x00106460 - 0x0010647F */
    FLASH_DF_BLOCK_804     = 0x00106480,    /*    32: 0x00106480 - 0x0010649F */
    FLASH_DF_BLOCK_805     = 0x001064A0,    /*    32: 0x001064A0 - 0x001064BF */
    FLASH_DF_BLOCK_806     = 0x001064C0,    /*    32: 0x001064C0 - 0x001064DF */
    FLASH_DF_BLOCK_807     = 0x001064E0,    /*    32: 0x001064E0 - 0x001064FF */
    FLASH_DF_BLOCK_808     = 0x00106500,    /*    32: 0x00106500 - 0x0010651F */
    FLASH_DF_BLOCK_809     = 0x00106520,    /*    32: 0x00106520 - 0x0010653F */
    FLASH_DF_BLOCK_810     = 0x00106540,    /*    32: 0x00106540 - 0x0010655F */
    FLASH_DF_BLOCK_811     = 0x00106560,    /*    32: 0x00106560 - 0x0010657F */
    FLASH_DF_BLOCK_812     = 0x00106580,    /*    32: 0x00106580 - 0x0010659F */
    FLASH_DF_BLOCK_813     = 0x001065A0,    /*    32: 0x001065A0 - 0x001065BF */
    FLASH_DF_BLOCK_814     = 0x001065C0,    /*    32: 0x001065C0 - 0x001065DF */
    FLASH_DF_BLOCK_815     = 0x001065E0,    /*    32: 0x001065E0 - 0x001065FF */
    FLASH_DF_BLOCK_816     = 0x00106600,    /*    32: 0x00106600 - 0x0010661F */
    FLASH_DF_BLOCK_817     = 0x00106620,    /*    32: 0x00106620 - 0x0010663F */
    FLASH_DF_BLOCK_818     = 0x00106640,    /*    32: 0x00106640 - 0x0010665F */
    FLASH_DF_BLOCK_819     = 0x00106660,    /*    32: 0x00106660 - 0x0010667F */
    FLASH_DF_BLOCK_820     = 0x00106680,    /*    32: 0x00106680 - 0x0010669F */
    FLASH_DF_BLOCK_821     = 0x001066A0,    /*    32: 0x001066A0 - 0x001066BF */
    FLASH_DF_BLOCK_822     = 0x001066C0,    /*    32: 0x001066C0 - 0x001066DF */
    FLASH_DF_BLOCK_823     = 0x001066E0,    /*    32: 0x001066E0 - 0x001066FF */
    FLASH_DF_BLOCK_824     = 0x00106700,    /*    32: 0x00106700 - 0x0010671F */
    FLASH_DF_BLOCK_825     = 0x00106720,    /*    32: 0x00106720 - 0x0010673F */
    FLASH_DF_BLOCK_826     = 0x00106740,    /*    32: 0x00106740 - 0x0010675F */
    FLASH_DF_BLOCK_827     = 0x00106760,    /*    32: 0x00106760 - 0x0010677F */
    FLASH_DF_BLOCK_828     = 0x00106780,    /*    32: 0x00106780 - 0x0010679F */
    FLASH_DF_BLOCK_829     = 0x001067A0,    /*    32: 0x001067A0 - 0x001067BF */
    FLASH_DF_BLOCK_830     = 0x001067C0,    /*    32: 0x001067C0 - 0x001067DF */
    FLASH_DF_BLOCK_831     = 0x001067E0,    /*    32: 0x001067E0 - 0x001067FF */
    FLASH_DF_BLOCK_832     = 0x00106800,    /*    32: 0x00106800 - 0x0010681F */
    FLASH_DF_BLOCK_833     = 0x00106820,    /*    32: 0x00106820 - 0x0010683F */
    FLASH_DF_BLOCK_834     = 0x00106840,    /*    32: 0x00106840 - 0x0010685F */
    FLASH_DF_BLOCK_835     = 0x00106860,    /*    32: 0x00106860 - 0x0010687F */
    FLASH_DF_BLOCK_836     = 0x00106880,    /*    32: 0x00106880 - 0x0010689F */
    FLASH_DF_BLOCK_837     = 0x001068A0,    /*    32: 0x001068A0 - 0x001068BF */
    FLASH_DF_BLOCK_838     = 0x001068C0,    /*    32: 0x001068C0 - 0x001068DF */
    FLASH_DF_BLOCK_839     = 0x001068E0,    /*    32: 0x001068E0 - 0x001068FF */
    FLASH_DF_BLOCK_840     = 0x00106900,    /*    32: 0x00106900 - 0x0010691F */
    FLASH_DF_BLOCK_841     = 0x00106920,    /*    32: 0x00106920 - 0x0010693F */
    FLASH_DF_BLOCK_842     = 0x00106940,    /*    32: 0x00106940 - 0x0010695F */
    FLASH_DF_BLOCK_843     = 0x00106960,    /*    32: 0x00106960 - 0x0010697F */
    FLASH_DF_BLOCK_844     = 0x00106980,    /*    32: 0x00106980 - 0x0010699F */
    FLASH_DF_BLOCK_845     = 0x001069A0,    /*    32: 0x001069A0 - 0x001069BF */
    FLASH_DF_BLOCK_846     = 0x001069C0,    /*    32: 0x001069C0 - 0x001069DF */
    FLASH_DF_BLOCK_847     = 0x001069E0,    /*    32: 0x001069E0 - 0x001069FF */
    FLASH_DF_BLOCK_848     = 0x00106A00,    /*    32: 0x00106A00 - 0x00106A1F */
    FLASH_DF_BLOCK_849     = 0x00106A20,    /*    32: 0x00106A20 - 0x00106A3F */
    FLASH_DF_BLOCK_850     = 0x00106A40,    /*    32: 0x00106A40 - 0x00106A5F */
    FLASH_DF_BLOCK_851     = 0x00106A60,    /*    32: 0x00106A60 - 0x00106A7F */
    FLASH_DF_BLOCK_852     = 0x00106A80,    /*    32: 0x00106A80 - 0x00106A9F */
    FLASH_DF_BLOCK_853     = 0x00106AA0,    /*    32: 0x00106AA0 - 0x00106ABF */
    FLASH_DF_BLOCK_854     = 0x00106AC0,    /*    32: 0x00106AC0 - 0x00106ADF */
    FLASH_DF_BLOCK_855     = 0x00106AE0,    /*    32: 0x00106AE0 - 0x00106AFF */
    FLASH_DF_BLOCK_856     = 0x00106B00,    /*    32: 0x00106B00 - 0x00106B1F */
    FLASH_DF_BLOCK_857     = 0x00106B20,    /*    32: 0x00106B20 - 0x00106B3F */
    FLASH_DF_BLOCK_858     = 0x00106B40,    /*    32: 0x00106B40 - 0x00106B5F */
    FLASH_DF_BLOCK_859     = 0x00106B60,    /*    32: 0x00106B60 - 0x00106B7F */
    FLASH_DF_BLOCK_860     = 0x00106B80,    /*    32: 0x00106B80 - 0x00106B9F */
    FLASH_DF_BLOCK_861     = 0x00106BA0,    /*    32: 0x00106BA0 - 0x00106BBF */
    FLASH_DF_BLOCK_862     = 0x00106BC0,    /*    32: 0x00106BC0 - 0x00106BDF */
    FLASH_DF_BLOCK_863     = 0x00106BE0,    /*    32: 0x00106BE0 - 0x00106BFF */
    FLASH_DF_BLOCK_864     = 0x00106C00,    /*    32: 0x00106C00 - 0x00106C1F */
    FLASH_DF_BLOCK_865     = 0x00106C20,    /*    32: 0x00106C20 - 0x00106C3F */
    FLASH_DF_BLOCK_866     = 0x00106C40,    /*    32: 0x00106C40 - 0x00106C5F */
    FLASH_DF_BLOCK_867     = 0x00106C60,    /*    32: 0x00106C60 - 0x00106C7F */
    FLASH_DF_BLOCK_868     = 0x00106C80,    /*    32: 0x00106C80 - 0x00106C9F */
    FLASH_DF_BLOCK_869     = 0x00106CA0,    /*    32: 0x00106CA0 - 0x00106CBF */
    FLASH_DF_BLOCK_870     = 0x00106CC0,    /*    32: 0x00106CC0 - 0x00106CDF */
    FLASH_DF_BLOCK_871     = 0x00106CE0,    /*    32: 0x00106CE0 - 0x00106CFF */
    FLASH_DF_BLOCK_872     = 0x00106D00,    /*    32: 0x00106D00 - 0x00106D1F */
    FLASH_DF_BLOCK_873     = 0x00106D20,    /*    32: 0x00106D20 - 0x00106D3F */
    FLASH_DF_BLOCK_874     = 0x00106D40,    /*    32: 0x00106D40 - 0x00106D5F */
    FLASH_DF_BLOCK_875     = 0x00106D60,    /*    32: 0x00106D60 - 0x00106D7F */
    FLASH_DF_BLOCK_876     = 0x00106D80,    /*    32: 0x00106D80 - 0x00106D9F */
    FLASH_DF_BLOCK_877     = 0x00106DA0,    /*    32: 0x00106DA0 - 0x00106DBF */
    FLASH_DF_BLOCK_878     = 0x00106DC0,    /*    32: 0x00106DC0 - 0x00106DDF */
    FLASH_DF_BLOCK_879     = 0x00106DE0,    /*    32: 0x00106DE0 - 0x00106DFF */
    FLASH_DF_BLOCK_880     = 0x00106E00,    /*    32: 0x00106E00 - 0x00106E1F */
    FLASH_DF_BLOCK_881     = 0x00106E20,    /*    32: 0x00106E20 - 0x00106E3F */
    FLASH_DF_BLOCK_882     = 0x00106E40,    /*    32: 0x00106E40 - 0x00106E5F */
    FLASH_DF_BLOCK_883     = 0x00106E60,    /*    32: 0x00106E60 - 0x00106E7F */
    FLASH_DF_BLOCK_884     = 0x00106E80,    /*    32: 0x00106E80 - 0x00106E9F */
    FLASH_DF_BLOCK_885     = 0x00106EA0,    /*    32: 0x00106EA0 - 0x00106EBF */
    FLASH_DF_BLOCK_886     = 0x00106EC0,    /*    32: 0x00106EC0 - 0x00106EDF */
    FLASH_DF_BLOCK_887     = 0x00106EE0,    /*    32: 0x00106EE0 - 0x00106EFF */
    FLASH_DF_BLOCK_888     = 0x00106F00,    /*    32: 0x00106F00 - 0x00106F1F */
    FLASH_DF_BLOCK_889     = 0x00106F20,    /*    32: 0x00106F20 - 0x00106F3F */
    FLASH_DF_BLOCK_890     = 0x00106F40,    /*    32: 0x00106F40 - 0x00106F5F */
    FLASH_DF_BLOCK_891     = 0x00106F60,    /*    32: 0x00106F60 - 0x00106F7F */
    FLASH_DF_BLOCK_892     = 0x00106F80,    /*    32: 0x00106F80 - 0x00106F9F */
    FLASH_DF_BLOCK_893     = 0x00106FA0,    /*    32: 0x00106FA0 - 0x00106FBF */
    FLASH_DF_BLOCK_894     = 0x00106FC0,    /*    32: 0x00106FC0 - 0x00106FDF */
    FLASH_DF_BLOCK_895     = 0x00106FE0,    /*    32: 0x00106FE0 - 0x00106FFF */
    FLASH_DF_BLOCK_896     = 0x00107000,    /*    32: 0x00107000 - 0x0010701F */
    FLASH_DF_BLOCK_897     = 0x00107020,    /*    32: 0x00107020 - 0x0010703F */
    FLASH_DF_BLOCK_898     = 0x00107040,    /*    32: 0x00107040 - 0x0010705F */
    FLASH_DF_BLOCK_899     = 0x00107060,    /*    32: 0x00107060 - 0x0010707F */
    FLASH_DF_BLOCK_900     = 0x00107080,    /*    32: 0x00107080 - 0x0010709F */
    FLASH_DF_BLOCK_901     = 0x001070A0,    /*    32: 0x001070A0 - 0x001070BF */
    FLASH_DF_BLOCK_902     = 0x001070C0,    /*    32: 0x001070C0 - 0x001070DF */
    FLASH_DF_BLOCK_903     = 0x001070E0,    /*    32: 0x001070E0 - 0x001070FF */
    FLASH_DF_BLOCK_904     = 0x00107100,    /*    32: 0x00107100 - 0x0010711F */
    FLASH_DF_BLOCK_905     = 0x00107120,    /*    32: 0x00107120 - 0x0010713F */
    FLASH_DF_BLOCK_906     = 0x00107140,    /*    32: 0x00107140 - 0x0010715F */
    FLASH_DF_BLOCK_907     = 0x00107160,    /*    32: 0x00107160 - 0x0010717F */
    FLASH_DF_BLOCK_908     = 0x00107180,    /*    32: 0x00107180 - 0x0010719F */
    FLASH_DF_BLOCK_909     = 0x001071A0,    /*    32: 0x001071A0 - 0x001071BF */
    FLASH_DF_BLOCK_910     = 0x001071C0,    /*    32: 0x001071C0 - 0x001071DF */
    FLASH_DF_BLOCK_911     = 0x001071E0,    /*    32: 0x001071E0 - 0x001071FF */
    FLASH_DF_BLOCK_912     = 0x00107200,    /*    32: 0x00107200 - 0x0010721F */
    FLASH_DF_BLOCK_913     = 0x00107220,    /*    32: 0x00107220 - 0x0010723F */
    FLASH_DF_BLOCK_914     = 0x00107240,    /*    32: 0x00107240 - 0x0010725F */
    FLASH_DF_BLOCK_915     = 0x00107260,    /*    32: 0x00107260 - 0x0010727F */
    FLASH_DF_BLOCK_916     = 0x00107280,    /*    32: 0x00107280 - 0x0010729F */
    FLASH_DF_BLOCK_917     = 0x001072A0,    /*    32: 0x001072A0 - 0x001072BF */
    FLASH_DF_BLOCK_918     = 0x001072C0,    /*    32: 0x001072C0 - 0x001072DF */
    FLASH_DF_BLOCK_919     = 0x001072E0,    /*    32: 0x001072E0 - 0x001072FF */
    FLASH_DF_BLOCK_920     = 0x00107300,    /*    32: 0x00107300 - 0x0010731F */
    FLASH_DF_BLOCK_921     = 0x00107320,    /*    32: 0x00107320 - 0x0010733F */
    FLASH_DF_BLOCK_922     = 0x00107340,    /*    32: 0x00107340 - 0x0010735F */
    FLASH_DF_BLOCK_923     = 0x00107360,    /*    32: 0x00107360 - 0x0010737F */
    FLASH_DF_BLOCK_924     = 0x00107380,    /*    32: 0x00107380 - 0x0010739F */
    FLASH_DF_BLOCK_925     = 0x001073A0,    /*    32: 0x001073A0 - 0x001073BF */
    FLASH_DF_BLOCK_926     = 0x001073C0,    /*    32: 0x001073C0 - 0x001073DF */
    FLASH_DF_BLOCK_927     = 0x001073E0,    /*    32: 0x001073E0 - 0x001073FF */
    FLASH_DF_BLOCK_928     = 0x00107400,    /*    32: 0x00107400 - 0x0010741F */
    FLASH_DF_BLOCK_929     = 0x00107420,    /*    32: 0x00107420 - 0x0010743F */
    FLASH_DF_BLOCK_930     = 0x00107440,    /*    32: 0x00107440 - 0x0010745F */
    FLASH_DF_BLOCK_931     = 0x00107460,    /*    32: 0x00107460 - 0x0010747F */
    FLASH_DF_BLOCK_932     = 0x00107480,    /*    32: 0x00107480 - 0x0010749F */
    FLASH_DF_BLOCK_933     = 0x001074A0,    /*    32: 0x001074A0 - 0x001074BF */
    FLASH_DF_BLOCK_934     = 0x001074C0,    /*    32: 0x001074C0 - 0x001074DF */
    FLASH_DF_BLOCK_935     = 0x001074E0,    /*    32: 0x001074E0 - 0x001074FF */
    FLASH_DF_BLOCK_936     = 0x00107500,    /*    32: 0x00107500 - 0x0010751F */
    FLASH_DF_BLOCK_937     = 0x00107520,    /*    32: 0x00107520 - 0x0010753F */
    FLASH_DF_BLOCK_938     = 0x00107540,    /*    32: 0x00107540 - 0x0010755F */
    FLASH_DF_BLOCK_939     = 0x00107560,    /*    32: 0x00107560 - 0x0010757F */
    FLASH_DF_BLOCK_940     = 0x00107580,    /*    32: 0x00107580 - 0x0010759F */
    FLASH_DF_BLOCK_941     = 0x001075A0,    /*    32: 0x001075A0 - 0x001075BF */
    FLASH_DF_BLOCK_942     = 0x001075C0,    /*    32: 0x001075C0 - 0x001075DF */
    FLASH_DF_BLOCK_943     = 0x001075E0,    /*    32: 0x001075E0 - 0x001075FF */
    FLASH_DF_BLOCK_944     = 0x00107600,    /*    32: 0x00107600 - 0x0010761F */
    FLASH_DF_BLOCK_945     = 0x00107620,    /*    32: 0x00107620 - 0x0010763F */
    FLASH_DF_BLOCK_946     = 0x00107640,    /*    32: 0x00107640 - 0x0010765F */
    FLASH_DF_BLOCK_947     = 0x00107660,    /*    32: 0x00107660 - 0x0010767F */
    FLASH_DF_BLOCK_948     = 0x00107680,    /*    32: 0x00107680 - 0x0010769F */
    FLASH_DF_BLOCK_949     = 0x001076A0,    /*    32: 0x001076A0 - 0x001076BF */
    FLASH_DF_BLOCK_950     = 0x001076C0,    /*    32: 0x001076C0 - 0x001076DF */
    FLASH_DF_BLOCK_951     = 0x001076E0,    /*    32: 0x001076E0 - 0x001076FF */
    FLASH_DF_BLOCK_952     = 0x00107700,    /*    32: 0x00107700 - 0x0010771F */
    FLASH_DF_BLOCK_953     = 0x00107720,    /*    32: 0x00107720 - 0x0010773F */
    FLASH_DF_BLOCK_954     = 0x00107740,    /*    32: 0x00107740 - 0x0010775F */
    FLASH_DF_BLOCK_955     = 0x00107760,    /*    32: 0x00107760 - 0x0010777F */
    FLASH_DF_BLOCK_956     = 0x00107780,    /*    32: 0x00107780 - 0x0010779F */
    FLASH_DF_BLOCK_957     = 0x001077A0,    /*    32: 0x001077A0 - 0x001077BF */
    FLASH_DF_BLOCK_958     = 0x001077C0,    /*    32: 0x001077C0 - 0x001077DF */
    FLASH_DF_BLOCK_959     = 0x001077E0,    /*    32: 0x001077E0 - 0x001077FF */
    FLASH_DF_BLOCK_960     = 0x00107800,    /*    32: 0x00107800 - 0x0010781F */
    FLASH_DF_BLOCK_961     = 0x00107820,    /*    32: 0x00107820 - 0x0010783F */
    FLASH_DF_BLOCK_962     = 0x00107840,    /*    32: 0x00107840 - 0x0010785F */
    FLASH_DF_BLOCK_963     = 0x00107860,    /*    32: 0x00107860 - 0x0010787F */
    FLASH_DF_BLOCK_964     = 0x00107880,    /*    32: 0x00107880 - 0x0010789F */
    FLASH_DF_BLOCK_965     = 0x001078A0,    /*    32: 0x001078A0 - 0x001078BF */
    FLASH_DF_BLOCK_966     = 0x001078C0,    /*    32: 0x001078C0 - 0x001078DF */
    FLASH_DF_BLOCK_967     = 0x001078E0,    /*    32: 0x001078E0 - 0x001078FF */
    FLASH_DF_BLOCK_968     = 0x00107900,    /*    32: 0x00107900 - 0x0010791F */
    FLASH_DF_BLOCK_969     = 0x00107920,    /*    32: 0x00107920 - 0x0010793F */
    FLASH_DF_BLOCK_970     = 0x00107940,    /*    32: 0x00107940 - 0x0010795F */
    FLASH_DF_BLOCK_971     = 0x00107960,    /*    32: 0x00107960 - 0x0010797F */
    FLASH_DF_BLOCK_972     = 0x00107980,    /*    32: 0x00107980 - 0x0010799F */
    FLASH_DF_BLOCK_973     = 0x001079A0,    /*    32: 0x001079A0 - 0x001079BF */
    FLASH_DF_BLOCK_974     = 0x001079C0,    /*    32: 0x001079C0 - 0x001079DF */
    FLASH_DF_BLOCK_975     = 0x001079E0,    /*    32: 0x001079E0 - 0x001079FF */
    FLASH_DF_BLOCK_976     = 0x00107A00,    /*    32: 0x00107A00 - 0x00107A1F */
    FLASH_DF_BLOCK_977     = 0x00107A20,    /*    32: 0x00107A20 - 0x00107A3F */
    FLASH_DF_BLOCK_978     = 0x00107A40,    /*    32: 0x00107A40 - 0x00107A5F */
    FLASH_DF_BLOCK_979     = 0x00107A60,    /*    32: 0x00107A60 - 0x00107A7F */
    FLASH_DF_BLOCK_980     = 0x00107A80,    /*    32: 0x00107A80 - 0x00107A9F */
    FLASH_DF_BLOCK_981     = 0x00107AA0,    /*    32: 0x00107AA0 - 0x00107ABF */
    FLASH_DF_BLOCK_982     = 0x00107AC0,    /*    32: 0x00107AC0 - 0x00107ADF */
    FLASH_DF_BLOCK_983     = 0x00107AE0,    /*    32: 0x00107AE0 - 0x00107AFF */
    FLASH_DF_BLOCK_984     = 0x00107B00,    /*    32: 0x00107B00 - 0x00107B1F */
    FLASH_DF_BLOCK_985     = 0x00107B20,    /*    32: 0x00107B20 - 0x00107B3F */
    FLASH_DF_BLOCK_986     = 0x00107B40,    /*    32: 0x00107B40 - 0x00107B5F */
    FLASH_DF_BLOCK_987     = 0x00107B60,    /*    32: 0x00107B60 - 0x00107B7F */
    FLASH_DF_BLOCK_988     = 0x00107B80,    /*    32: 0x00107B80 - 0x00107B9F */
    FLASH_DF_BLOCK_989     = 0x00107BA0,    /*    32: 0x00107BA0 - 0x00107BBF */
    FLASH_DF_BLOCK_990     = 0x00107BC0,    /*    32: 0x00107BC0 - 0x00107BDF */
    FLASH_DF_BLOCK_991     = 0x00107BE0,    /*    32: 0x00107BE0 - 0x00107BFF */
    FLASH_DF_BLOCK_992     = 0x00107C00,    /*    32: 0x00107C00 - 0x00107C1F */
    FLASH_DF_BLOCK_993     = 0x00107C20,    /*    32: 0x00107C20 - 0x00107C3F */
    FLASH_DF_BLOCK_994     = 0x00107C40,    /*    32: 0x00107C40 - 0x00107C5F */
    FLASH_DF_BLOCK_995     = 0x00107C60,    /*    32: 0x00107C60 - 0x00107C7F */
    FLASH_DF_BLOCK_996     = 0x00107C80,    /*    32: 0x00107C80 - 0x00107C9F */
    FLASH_DF_BLOCK_997     = 0x00107CA0,    /*    32: 0x00107CA0 - 0x00107CBF */
    FLASH_DF_BLOCK_998     = 0x00107CC0,    /*    32: 0x00107CC0 - 0x00107CDF */
    FLASH_DF_BLOCK_999     = 0x00107CE0,    /*    32: 0x00107CE0 - 0x00107CFF */
    FLASH_DF_BLOCK_1000    = 0x00107D00,    /*    32: 0x00107D00 - 0x00107D1F */
    FLASH_DF_BLOCK_1001    = 0x00107D20,    /*    32: 0x00107D20 - 0x00107D3F */
    FLASH_DF_BLOCK_1002    = 0x00107D40,    /*    32: 0x00107D40 - 0x00107D5F */
    FLASH_DF_BLOCK_1003    = 0x00107D60,    /*    32: 0x00107D60 - 0x00107D7F */
    FLASH_DF_BLOCK_1004    = 0x00107D80,    /*    32: 0x00107D80 - 0x00107D9F */
    FLASH_DF_BLOCK_1005    = 0x00107DA0,    /*    32: 0x00107DA0 - 0x00107DBF */
    FLASH_DF_BLOCK_1006    = 0x00107DC0,    /*    32: 0x00107DC0 - 0x00107DDF */
    FLASH_DF_BLOCK_1007    = 0x00107DE0,    /*    32: 0x00107DE0 - 0x00107DFF */
    FLASH_DF_BLOCK_1008    = 0x00107E00,    /*    32: 0x00107E00 - 0x00107E1F */
    FLASH_DF_BLOCK_1009    = 0x00107E20,    /*    32: 0x00107E20 - 0x00107E3F */
    FLASH_DF_BLOCK_1010    = 0x00107E40,    /*    32: 0x00107E40 - 0x00107E5F */
    FLASH_DF_BLOCK_1011    = 0x00107E60,    /*    32: 0x00107E60 - 0x00107E7F */
    FLASH_DF_BLOCK_1012    = 0x00107E80,    /*    32: 0x00107E80 - 0x00107E9F */
    FLASH_DF_BLOCK_1013    = 0x00107EA0,    /*    32: 0x00107EA0 - 0x00107EBF */
    FLASH_DF_BLOCK_1014    = 0x00107EC0,    /*    32: 0x00107EC0 - 0x00107EDF */
    FLASH_DF_BLOCK_1015    = 0x00107EE0,    /*    32: 0x00107EE0 - 0x00107EFF */
    FLASH_DF_BLOCK_1016    = 0x00107F00,    /*    32: 0x00107F00 - 0x00107F1F */
    FLASH_DF_BLOCK_1017    = 0x00107F20,    /*    32: 0x00107F20 - 0x00107F3F */
    FLASH_DF_BLOCK_1018    = 0x00107F40,    /*    32: 0x00107F40 - 0x00107F5F */
    FLASH_DF_BLOCK_1019    = 0x00107F60,    /*    32: 0x00107F60 - 0x00107F7F */
    FLASH_DF_BLOCK_1020    = 0x00107F80,    /*    32: 0x00107F80 - 0x00107F9F */
    FLASH_DF_BLOCK_1021    = 0x00107FA0,    /*    32: 0x00107FA0 - 0x00107FBF */
    FLASH_DF_BLOCK_1022    = 0x00107FC0,    /*    32: 0x00107FC0 - 0x00107FDF */
    FLASH_DF_BLOCK_1023    = 0x00107FE0,    /*    32: 0x00107FE0 - 0x00107FFF */
    FLASH_DF_BLOCK_INVALID = 0x00108000     /*    32: Can't write beyond 0x00107FFF */

} flash_block_address_t;

typedef struct _rom_block_sizes
{
 uint32_t num_blocks;                     // number of blocks at this size
 uint32_t block_size;                     // Size of each block
}rom_block_sizes_t;

typedef struct _rom_block_info
{
 uint32_t start_addr;                   // starting address for this block section
 uint32_t end_addr;                     // ending (up to and including this) address
 uint16_t block_number;                 // the rom block number for this address queried
 uint32_t thisblock_stAddr;             // the starting address for the above block #
 uint32_t block_size;                   // Size of this block

}rom_block_info_t;

#define NUM_BLOCK_TABLE_ENTRIES 5
static rom_block_sizes_t g_flash_RomBlockSizes[NUM_BLOCK_TABLE_ENTRIES] = {
         8,  4096,    /* 8 blocks of 4K   */
        30, 16384,    /* 30 blocks of 16K */
        16, 32768,    /* 16 blocks of 32K */
        16, 65536,     /* 16 blocks of 64K */
        0,  0
};


/*  According to HW Manual the Max Programming Time for 128 bytes (ROM)
    is 12ms.  This is with a FCLK of 50MHz. The calculation below
    calculates the number of ICLK ticks needed for the timeout delay.
    The 12ms number is adjusted linearly depending on the FCLK frequency.
*/
#define WAIT_MAX_ROM_WRITE \
        ((int32_t)(12000 * (50.0/(MCU_CFG_FCLK_HZ/1000000)))*(MCU_CFG_ICLK_HZ/1000000))

/*  According to HW Manual the Max Programming Time for 2 bytes
    (Data Flash) is 2ms.  This is with a FCLK of 50MHz. The calculation
    below calculates the number of ICLK ticks needed for the timeout delay.
    The 5ms number is adjusted linearly depending on the FCLK frequency.
*/
#define WAIT_MAX_DF_WRITE \
        ((int32_t)(2000 * (50.0/(MCU_CFG_FCLK_HZ/1000000)))*(MCU_CFG_ICLK_HZ/1000000))

/*  According to HW Manual the Max Blank Check time for 2k bytes
    (Data Flash) is 0.7ms.  This is with a FCLK of 50MHz. The calculation
    below calculates the number of ICLK ticks needed for the timeout delay.
    The 0.7ms number is adjusted linearly depending on the FCLK frequency.
*/
#define WAIT_MAX_BLANK_CHECK \
        ((int32_t)(700 * (50.0/(MCU_CFG_FCLK_HZ/1000000)))*(MCU_CFG_ICLK_HZ/1000000))
        
/*  According to HW Manual the max timeout value when using the peripheral
    clock notification command is 60us. This is with a FCLK of 50MHz. The 
    calculation below calculates the number of ICLK ticks needed for the 
    timeout delay. The 10us number is adjusted linearly depending on 
    the FCLK frequency.
*/
#define WAIT_MAX_NOTIFY_FCU_CLOCK \
        ((int32_t)(60 * (50.0/(MCU_CFG_FCLK_HZ/1000000)))*(MCU_CFG_ICLK_HZ/1000000))

/*  According to HW Manual the Max Erasure Time for a 64kB block is
    around 1152ms.  This is with a FCLK of 50MHz. The calculation below
    calculates the number of ICLK ticks needed for the timeout delay.
    The 1152ms number is adjusted linearly depending on the FCLK frequency.
*/
#define WAIT_MAX_ERASE \
        ((int32_t)(1152000 * (50.0/(MCU_CFG_FCLK_HZ/1000000)))*(MCU_CFG_ICLK_HZ/1000000))

/******************************************************************************
Error checking
******************************************************************************/
/* FCLK must be between 4MHz and 50MHz. */
#if (MCU_CFG_FCLK_HZ > 50000000) || (MCU_CFG_FCLK_HZ < 4000000)
    #error "ERROR - Flash API - FCLK on RX63N must be between 4MHz and 50MHz!"
#endif

#endif /* FLASH_API_RX63N_H */
